<?php
/*
  $Id: easypopulate.php,v 3.0 20/12/2019

  Designed for osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2013 Craig Poole
  Portions Copyright 2019 Jack York @oscommerce-solution.com

  Released under the GNU General Public License
*/
require('includes/application_top.php');
require('includes/functions/easypopulate_functions.php');
if (file_exists('includes/functions/easypopulate_functions_pro.php')) require 'includes/functions/easypopulate_functions_pro.php';
require 'includes/classes/table_block_easy_populate.php';
require_once 'includes/languages/' . $_SESSION['language'] . '/easypopulate.php';

define('OVERWRITE_IMAGES', false); //used with the image upload options

$msgArray = ['msg' => '', 'color' => 'text-white', 'bkgnd' => 'bg-success'];
$system = GetSystemDetails();

if (isset($_POST['action']) && $_POST['action'] == 'settings') {
    $options_array = SaveDefaultOptions($system);
} else {
    $options_array = GetDefaultOptions($system);
}

// Current EP Version
define ('EP_CURRENT_VERSION', '3.4');
define ('EP_SHOW_EP_SETTINGS', true); // display in right column
define ('EP_TEMP_DIRECTORY', DIR_FS_CATALOG . 'temp/'); 
define ('EP_SPLIT_MAX_RECORDS', 800);  // default, seems to work for most people.  Reduce if you hit timeouts
define ('EP_DEFAULT_IMAGE_MANUFACTURER', ''); 
define ('EP_DEFAULT_IMAGE_PRODUCT', ''); 
define ('EP_DEFAULT_IMAGE_CATEGORY', ''); 
define ('EP_PRODUCTS_IMAGES_MAX', 6);  //**** Large Images osc 2.3.1 Supportg ****
define ('EP_TEXT_ACTIVE', 'Active'); //**** Status Field Setting ****
define ('EP_TEXT_INACTIVE', 'Inactive'); // Set the v_status field to "Inactive" if you want the status=0 in the system
define ('EP_DELETE_IT', 'Delete'); // Set the v_status field to "Delete" if you want to remove the item from the system
define ('EP_INACTIVATE_ZERO_QUANTITIES', false);  // If zero_qty_inactive is true, then items with zero qty will automatically be inactive in the store.
define ('EP_PRICE_WITH_TAX', false);  // default is false
define ('EP_PRECISION', 2);  // Price calculation precision

// **** Quote -> Escape character conversion ****
// If you have extensive html in your descriptions and it's getting mangled on upload, turn this off
// set to true = replace quotes with escape characters
// set to false = no quote replacement
define ('EP_REPLACE_QUOTES', false);  // default is false

// **** Field Separator ****
// change this if you can't use the default of tabs
// Tab is the default, comma and semicolon are commonly supported by various progs
// Remember, if your descriptions contain this character, you will confuse EP!
// if EP_EXCEL_SAFE_OUTPUT if false (below) you must make EP_PRESERVE_TABS_CR_LF false also.
$ep_separator = "\t"; // tab is default
//$ep_separator = ',';  // comma
//$ep_separator = ';';  // semi-colon
//$ep_separator = '~';  // tilde
//$ep_separator = '*';  // splat

// *** Excel safe output ***
// this setting will supersede the previous $ep_separator setting and create a file
// that excel will import without spanning cells from embedded commas or tabs in your products.
// if EP_EXCEL_SAFE_OUTPUT if false (below) you must make EP_PRESERVE_TABS_CR_LF false also.
define ('EP_EXCEL_SAFE_OUTPUT', true); // default is: true

if (EP_EXCEL_SAFE_OUTPUT == true) { 
    if ($language == 'english') { 
        $ep_separator = ',';  // comma
    } elseif ($language == 'german') {
        $ep_separator = ';';  // semi-colon
    } else {
        $ep_separator = ',';  // comma  // default for all others.
    }
}

// if EP_EXCEL_SAFE_OUTPUT if true (above) there is an alternative line parsing routine
//  provided by Maynard that will use a manual php approach.  There is a bug in some
// PHP versions that may require you to use this routine.  This should also provide proper
// parsing when quotes are used within a string. I suspect this should also resolve an issue
// recently reported in which characters with a german "Umlaute" like  at the Beginning 
// of some text, they will disappear when importing some csv-file, reported by TurboTB.
define ('EP_EXCEL_SAFE_OUTPUT_ALT_PARCE', false); // default is: false

// *** Preserve Tabs, Carriage returns and Line feeds ***
// this setting will preserve the special chars that can cause problems in 
// a text based output. When used with EP_EXCEL_SAFE_OUTPUT, it will safely
// preserve these elements in the export and import.
define ('EP_PRESERVE_TABS_CR_LF', false); // default is: false

// **** Max Category Levels ****
// change this if you need more or fewer categories.
// set this to the maximum depth of your categories.
define ('EP_MAX_CATEGORIES', 7); // default is 7

// VJ product attributes begin
// **** Product Attributes ****
// change this to false, if do not want to download product attributes
define ('EP_PRODUCTS_WITH_ATTRIBUTES', true);  // default is true

define ('EP_PRODUCTS_ATTRIBUTES_STOCK', false); // change this to true, if you use QTYpro and want to set attributes stock with EP.

// change this if you want to download only selected product options (attributes).
// If you have a lot of product options, and your output file exceeds 256 columns, 
// which is the max. limit MS Excel is able to handle, then load-up this array with
// attributes to skip when generating the export.
$attribute_options_select = '';
// $attribute_options_select = array('Size', 'Model'); // uncomment and fill with product options name you wish to download // comment this line, if you wish to download all product options
// VJ product attributes end

// if your store has the Ultimate SEO addon installed, then set this to true
// Doesn't worj with SEO 5.
define ('EP_SEF_URLS', false);  // default is false

// ******************************************************************
// BEGIN Define Custom Fields for your products database
// ******************************************************************
// the following line is always left as is.
$custom_fields = array();
//
// The following setup will allow you to define any additional 
// field into the "products" and "products_description" tables
// in your shop. If you have  installed a custom contribution
// that adds fields to these tables you may simply and easily add
// them to the EasyPopulate system.
//
// ********************
// ** products table **
// Lets say you have added a field to your "products" table called
// "products_upc". The header name in your import file will be
// called "v_products_upc".  Then below you will change the line
// that looks like this (without the comment double-slash at the beginning):
// $custom_fields['products'] = array(); // this line is used if you have no custom fields to import/export
//
// TO:
// $custom_fields['products'] = array( 'products_upc' => 'UPC' );
//
// If you have multiple fields this is what it would look like:
// $custom_fields['products'] = array( 'products_upc' => 'UPC', 'products_restock_quantity' => 'Restock' );
//
// ********************************
// ** products_description table **
// Lets say you have added a field to your "products_description" table called
// "products_short_description". The header name in your import file will be
// called "v_products_short_description_1" for English, "v_products_short_description_2" for German,
// "v_products_short_description_3" for Spanish. Other languages will vary. Be sure to use the 
// langugage ID of the custom language you installed if it is other then the original
// 3 installed languages of osCommerce. If you are unsure what language ID you need to
// use, do a complete export and examine the file headers EasyPopulate produces.
//
// Then below you will change the line that looks like this (without the comment double-slash at the beginning):
// $custom_fields['products_description'] = array(); // this line is used if you have no custom fields to import/export
//
// TO:
// $custom_fields['products_description'] = array( 'products_short_description' => 'short' );
//
// If you have multiple fields this is what it would look like:
// $custom_fields['products_description'] = array( 'products_short_description' => 'short', 'products_viewed' => 'Viewed' );
//
// the array format is: array( 'table_field_name' => 'Familiar Name' )
// the array key ('table_field_name') is always the exact name of the 
// field in the table. The array value ('Familiar Name') is any text
// name that will be used in the custom EP export download checkbox.
//
// I believe this will only work for text/varchar and numeric field
// types.  If your custom field is a date/time or any other type, you
// may need to incorporate custom code to correctly import your data.
//

$custom_fields['products'] = array(); // this line is used if you have no custom fields to import/export
$custom_fields['products_description'] = array(); // this line is used if you have no custom fields to import/export

//
// FINAL NOTE: this currently only works with the "products" & "products_description" table.
// If it works well and I don't get a plethora of problems reported,
// I may expand it to more tables. Feel free to make requests, but
// as always, only as me free time allows.
//
// ******************************************************************
// END Define Custom Fields for your products database
// ******************************************************************

// ****************************************
// Google Shopping configuration variables
// ****************************************

// **** Google Shopping product info page path ****
// This isn't used if the EP_SEF_URLS setting is set to true.
define ('EP_GOOGLE_SHOPPING_PRODUCT_INFO_PATH', HTTP_CATALOG_SERVER . DIR_WS_CATALOG . "product_info.php");

// **** Google Shopping product image path ****
// Set this to the path to your images directory
define ('EP_GOOGLE_SHOPPING_IMAGE_PATH', HTTP_CATALOG_SERVER . DIR_WS_CATALOG . 'images.');

// **** Google Shopping Currency Setting
define ('EP_GOOGLE_SHOPPING_CURRENCY', 'USD');  // default is 'USD'

// ****************************************
// End: Google Shopping configuration variables
// 

// ***********************************
// *** Other Contributions Support ***
// ***********************************

// Additional Images v2.1.1
define ('EP_QPBP_MAX', 6);  // default is 6, maximum number of columns

//*******************************
//*******************************
// E N D
// C O N F I G U R A T I O N
// V A R I A B L E S
//*******************************
//*******************************

//*******************************
//*******************************
// S T A R T
// INITIALIZATION
//*******************************
//*******************************

// modify tableBlock for use here.
class epbox extends tableBlock_easy_populate {
    // constructor
    function __construct($contents, $direct_ouput = true) {
        $this->table_width = '';
        if (!empty($contents) && $direct_ouput == true) {
            echo $this->tableBlock($contents);
        }
    }
    // only member function
    function output($contents) {
        return $this->tableBlock($contents);
    }
}

if (!empty($languages_id) && !empty($language)) {
    define ('EP_DEFAULT_LANGUAGE_ID', $languages_id);
    define ('EP_DEFAULT_LANGUAGE_NAME', $language);
} else {
    //elari check default language_id from configuration table DEFAULT_LANGUAGE
    $epdlanguage_query = tep_db_query("select languages_id, name from languages where code = '" . DEFAULT_LANGUAGE . "'");
    if (tep_db_num_rows($epdlanguage_query) > 0) {
        $epdlanguage = tep_db_fetch_array($epdlanguage_query);
        define ('EP_DEFAULT_LANGUAGE_ID', $epdlanguage['languages_id']);
        define ('EP_DEFAULT_LANGUAGE_NAME', $epdlanguage['name']);
    } else {
        $msgArray['msg'] = 'Strange but there is no default language to work... That may not happen, just in case... ';
        $msgArray['color'] = 'text-white';
        $msgArray['bkgnd'] = 'bg-danger';
    }
}

$languages = tep_get_languages();

// VJ product attributes begin
$attribute_options_array = [];

if (EP_PRODUCTS_WITH_ATTRIBUTES == true) {
    if (tep_not_null($attribute_options_select) && (count($attribute_options_select) > 0)) {
        foreach ($attribute_options_select as $value) {
            $attribute_options_query = "select distinct products_options_id from products_options where products_options_name = '" . $value . "'";

            $attribute_options_values = tep_db_query($attribute_options_query);

            if ($attribute_options = tep_db_fetch_array($attribute_options_values)){
                $attribute_options_array[] = array('products_options_id' => $attribute_options['products_options_id']);
            }
        }
    } else {
        $attribute_options_query = "select distinct products_options_id from products_options order by products_options_id";
        $attribute_options_values = tep_db_query($attribute_options_query);

        while ($attribute_options = tep_db_fetch_array($attribute_options_values)){
            $attribute_options_array[] = array('products_options_id' => $attribute_options['products_options_id']);
        }
    }
}
// VJ product attributes end

// these are the fields that will be defaulted to the current values in 
// the database if they are not found in the incoming file
$default_these = array();
foreach ($languages as $key => $lang){
    $default_these[] = 'v_products_name_' . $lang['id'];
    $default_these[] = 'v_products_description_' . $lang['id'];
    $default_these[] = 'v_products_url_' . $lang['id'];
    foreach ($custom_fields['products_description'] as $key => $name) { 
        $default_these[] = 'v_' . $key . '_' . $lang['id'];
    }
    if ($options_array['option_header_tags_seo']) {
        $default_these[] = 'v_products_seo_title_' . $lang['id'];
        $default_these[] = 'v_products_seo_description_' . $lang['id'];
        $default_these[] = 'v_products_seo_keywords_' . $lang['id'];
    }
}

$default_these[] = 'v_products_image';
foreach ($custom_fields['products'] as $key => $name) { 
    $default_these[] = 'v_' . $key;
}
// build images fields. Note: this building limited!
if ($options_array['option_product_images']) { 
    //$default_these[] = 'v_products_images_htmlcontent';
    for ($i=1; $i <= EP_PRODUCTS_IMAGES_MAX+1; ++$i) {
      //  $default_these[] = 'v_products_images_image_' . $i;
      //  $default_these[] = 'v_products_images_htmlcontent_' . $i;
    }
}

// build images fields. Note: this building limited!
if ($options_array['option_quantity_prices']) { 
  //$default_these[] = 'v_products_images_htmlcontent';
  for ($i=1;$i<=EP_QPBP_MAX+1;$i++) {
        $default_these[] = 'v_products_qpbp_price' . $i;
        $default_these[] = 'v_products_qpbp_qty_' . $i;
  }
}

if ($options_array['option_mvs']) { 
  $default_these[] = 'v_vendor';
}

if ($options_array['option_pdf_upload']) { 
  $default_these[] = 'v_products_pdfupload';
  $default_these[] = 'v_products_fileupload';
}

if ($options_array['option_master_products']) { 
  $default_these[] = 'v_products_model_id';
  $default_these[] = 'v_products_master';
  $default_these[] = 'v_products_master_status';  
}

$default_these[] = 'v_categories_id';
$default_these[] = 'v_products_price';
$default_these[] = 'v_products_quantity';
$default_these[] = 'v_products_weight';
$default_these[] = 'v_status_current';
$default_these[] = 'v_date_avail';
$default_these[] = 'v_date_added';
$default_these[] = 'v_tax_class_title';
$default_these[] = 'v_manufacturers_name';
$default_these[] = 'v_manufacturers_id';

$filelayout = '';
$filelayout_count = '';
$filelayout_sql = '';
$fileheaders = '';

if ( isset($_GET['dltype']) ) {
    // if dltype is set, then create the filelayout.  Otherwise it gets read from the uploaded file
    list($filelayout, $filelayout_count, $filelayout_sql, $fileheaders) = ep_create_filelayout($_GET['dltype'], $attribute_options_array, $languages, $custom_fields); // get the right filelayout for this download
}

//*******************************
//*******************************
// E N D
// INITIALIZATION
//*******************************
//*******************************

//*******************************
//*******************************
// DOWNLOAD FILE (EXPORT)
//*******************************
//*******************************
    if ( isset($_GET['download']) && ($_GET['download'] == 'stream' or $_GET['download'] == 'activestream' or $_GET['download'] == 'tempfile') ){
      $filestring = ""; // this holds the csv file we want to download
      $result = tep_db_query($filelayout_sql);
      $row = tep_db_fetch_array($result);
            
      // $EXPORT_TIME=time();  // start export time when export is started.
      $EXPORT_TIME = strftime('%Y%b%d-%H%I');
      $EXPORT_TIME = (isset($dltype ) && $dltype == "google_shopping" ? "Google ShoppingEP" . $EXPORT_TIME : "EP" . $EXPORT_TIME);
    
    // Here we need to allow for the mapping of internal field names to external field names
    // default to all headers named like the internal ones
    // the field mapping array only needs to cover those fields that need to have their name changed
    if ( tep_not_null($fileheaders) && count($fileheaders) != 0 ){
        $filelayout_header = $fileheaders; // if they gave us fileheaders for the dl, then use them
    } else {
        $filelayout_header = $filelayout; // if no mapping was spec'd use the internal field names for header names
    }

    //We prepare the table heading with layout values
    foreach( $filelayout_header as $key => $value ){
        $filestring .= $key . $ep_separator;
    }
    // now lop off the trailing tab
    $filestring = substr($filestring, 0, strlen($filestring)-1);

    // set the type
    $endofrow = ( isset($dltype) && $dltype == 'google_shopping' ? "\n" : $ep_separator . 'EOREOR' . "\n");
    $filestring .= $endofrow;

    if ($_GET['download'] == 'activestream'){
      //		header('Content-Transfer-Encoding: none');
      if (EP_EXCEL_SAFE_OUTPUT == true) {
          header("Content-type: text/x-csv");
          //		header('Content-type: text/x-csv; charset="utf-8"');
          //		header("Content-type: application/vnd.ms-excel");
          //		header('Content-type: application/vnd.ms-excel; charset="utf-8"');
      } else {
          header("Content-type: text/plain");
      }
      header("Content-disposition: attachment; filename=$EXPORT_TIME" . ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"));
      // Changed if using SSL, helps prevent program delay/timeout (add to backup.php also)
      if ($request_type== 'NONSSL'){
        header("Pragma: no-cache");
      } else {
        header("Pragma: ");
      }
      header("Expires: 0");
      echo $filestring;
    }

    $num_of_langs = count($languages);
    while ($row) {
        if (isset($_GET['dltype']) && $_GET['dltype'] == 'google_shopping') {
            // if the filelayout says we need a products_name, get it
            // build the long full google_shopping image path
            $row['v_products_fullpath_image'] = EP_GOOGLE_SHOPPING_IMAGE_PATH . $row['v_products_image'];
            // Other google_shopping defaults go here for now
            $row['v_google_shopping_quantitylevel']     = ($row['v_products_quantity'] ?? 1);
            $row['v_google_shopping_manufacturer_id']   = '';
            $row['v_google_shopping_exp_date']          = date('Y-m-d', strtotime('+30 days'));
            $row['v_google_shopping_product_type']      = ($row['v_categories_id'] ?? '');
            $row['v_google_shopping_product_id']        = $row['v_products_model'];
            $row['v_google_shopping_currency']          = EP_GOOGLE_SHOPPING_CURRENCY;
        }

        $row['v_products_model'] = str_replace(',', '&#44;', $row['v_products_model']);      
        //$row['v_products_model'] = '"' . $row['v_products_model'] . '"';      
       // $row['v_products_model'] = $row['v_products_model'];      
        
        // names and descriptions require that we loop thru all languages that are turned on in the store
        foreach ($languages as $key => $lang) {
            $lid = $lang['id'];

            // for each language, get the description and set the vals
            $sql2 = "SELECT *
                FROM products_description
                WHERE
                    products_id = " . $row['v_products_id'] . " AND
                    language_id = '" . $lid . "'
                ";
            $result2 = tep_db_query($sql2);
            $row2 =  tep_db_fetch_array($result2);
          
          
            //$row['v_products_name_' . $lid]          = $row2['products_name'];
            //$row['v_products_name_' . $lid]          = '"' . $row2['products_name'] . '"';
            $row['v_products_name_' . $lid]          = str_replace(',', '&#44;', $row2['products_name']);
 
          //  $row['v_products_description_' . $lid]   = $row2['products_description'];
           // $row['v_products_description_' . $lid]   = '"' . $row2['products_description'] . '"';
            $row['v_products_description_' . $lid]   = str_replace(',', '&#44;', $row2['products_description']);

            if (EP_SEF_URLS == true){
                $cd = getcwd();
                chdir(DIR_FS_CATALOG);
                require_once DIR_FS_CATALOG.'includes/functions/href_link_admin.php';
                $row['v_products_url_' . $lid] = dtep_href_link('product_info.php', 'products_id=' .$row['v_products_id']);
                $row['v_google_shopping_products_url_' . $lid] = $row['v_products_url_' . $lid];
                chdir($cd);
            } else {
                $apply_language = ($num_of_langs > 1 ? '&language=' . $lid : '');
                $row['v_products_url_' . $lid] = EP_GOOGLE_SHOPPING_PRODUCT_INFO_PATH . '?products_id=' . $row['v_products_id'] . $apply_language;
                $row['v_google_shopping_products_url_' . $lid] = $row['v_products_url_' . $lid];
            }

            foreach ($custom_fields['products_description'] as $key => $name) { 
                $row['v_' . $key . '_' . $lid] = $row2[$key];
            }
            
            // google_shopping advanced format needs the quotes around the name and desc
            $row['v_google_shopping_products_name_' . $lid] = '"' . strip_tags(str_replace('"','""',$row2['products_name'])) . '"';
            $row['v_google_shopping_products_description_' . $lid] = '"' . strip_tags(str_replace('"','""',$row2['products_description'])) . '"';

            // support for Header Tags SEO
            if(isset($filelayout['v_products_seo_title_' . $lid])){
                $row['v_products_seo_title_' . $lid] = str_replace(',','&#44;',$row2['products_seo_title']);
                $row['v_products_seo_description_' . $lid] = str_replace(',','&#44;',$row2['products_seo_description']);
                $row['v_products_seo_keywords_' . $lid] = str_replace(',','&#44;',$row2['products_seo_keywords']);
            }
            // end support for Header Tags SEO		
        }
        
        // get data from products images table
        if ($options_array['option_product_images']) {
            //echo "SELECT * FROM products_images WHERE products_id = '" . (int)$row['v_products_id'] . "' limit " . EP_PRODUCTS_IMAGES_MAX;
            
            for ($i = 1; $i < EP_PRODUCTS_IMAGES_MAX + 1; ++$i) {
                $row['v_products_images_image_'.$i] = $row['v_products_images_htmlcontent_'.$i] = '';
            }
 
            $i = 1;
            $pi_result = tep_db_query("SELECT * FROM products_images WHERE products_id = '" . (int)$row['v_products_id'] . "' limit " . EP_PRODUCTS_IMAGES_MAX);
            if (tep_db_num_rows($pi_result)) {
                while ($pi_row = tep_db_fetch_array($pi_result)) {
                    $row['v_products_images_image_'.$i] = $row['v_products_images_htmlcontent_'.$i] = ''; //placeholders
                    if (! empty($pi_row['image'])) {
                        $row['v_products_images_image_'.$i] = $pi_row['image'];
                    }
                    if (! empty($pi_row['htmlcontent'])) {
                        $row['v_products_images_htmlcontent_'.$i] = $pi_row['htmlcontent'];
                    }
                    $i++;
                }
            } else {
                for ($i = 1; $i <= EP_PRODUCTS_IMAGES_MAX + 1; ++$i) {
                    $row['v_products_images_image_'.$i] = $row['v_products_images_htmlcontent_'.$i] = ''; //placeholders
                }
            } 
        }

        // get data from products images table
        if ($options_array['option_quantity_prices']) {
            $i = 1;
            $pi_result = tep_db_query("SELECT * FROM products_price_break WHERE products_id= " . $row['v_products_id'] . " limit " . EP_QPBP_MAX);
            while ($pi_row = tep_db_fetch_array($pi_result)) {
                $row['v_products_qpbp_price_'.$i] = $pi_row['products_price'];
                $row['v_products_qpbp_qty_'.$i] = $pi_row['products_qty'];
                $i++;
            }
        }		
        
        if ($options_array['option_mvs']) { 
          $vend_result = tep_db_query("select vendors_name from vendors where vendors_id = " . $row['v_vendor_id'] . "");
          if ($vend_row = tep_db_fetch_array($vend_result)) {
            $row['v_vendor'] = $vend_row['vendors_name'];
          }
        }

        // for the categories, we need to keep looping until we find the root category
        // start with v_categories_id
        // Get the category description
        // set the appropriate variable name
        // if parent_id is not null, then follow it up.
        // we'll populate an aray first, then decide where it goes in the
        $thecategory_id = ($row['v_categories_id'] ?? null);
        $fullcategory = ''; // this will have the entire category stack for google_shopping
        for( $categorylevel=1; $categorylevel <= EP_MAX_CATEGORIES; ++$categorylevel) {
            if ($thecategory_id){

                $sql3 = "SELECT parent_id, 
                    categories_image
                   FROM categories
                   WHERE    
                    categories_id = " . $thecategory_id . '';
                $result3 = tep_db_query($sql3);
                if ($row3 = tep_db_fetch_array($result3)) {
                   $temprow['v_categories_image_' . $categorylevel] = $row3['categories_image'];
                }

                foreach ($languages as $key => $lang) {
                    $sql2 = "SELECT categories_name FROM categories_description
                        WHERE  categories_id = " . $thecategory_id . " AND language_id = " . (int)$lang['id'];
                    $result2 = tep_db_query($sql2);
                    if ($row2 =  tep_db_fetch_array($result2)) {
                        $temprow['v_categories_name_' . $categorylevel . '_' . $lang['id']] = '"' . $row2['categories_name'] . '"';
                    }
                    if ($lang['id'] == '1') {
                        //$fullcategory .= " > " . $row2['categories_name'];
                        $fullcategory = $row2['categories_name'] . " > " . $fullcategory;
                    }
                }

                // now get the parent ID if there was one
                $theparent_id = $row3['parent_id'];
                if ($theparent_id != ''){
                    // there was a parent ID, lets set thecategoryid to get the next level
                    $thecategory_id = $theparent_id;
                } else {
                    // we have found the top level category for this item,
                    $thecategory_id = false;
                }
          
            } else {
                $temprow['v_categories_image_' . $categorylevel] = '';
                foreach ($languages as $key => $lang){
                    $temprow['v_categories_name_' . $categorylevel . '_' . $lang['id']] = '';
                }
            }
        }

        // now trim off the last ">" from the category stack
        $tmpCategoryName = substr($fullcategory,0,strlen($fullcategory)-3);
        $row['v_category_fullpath'] = '"' . $tmpCategoryName . '"';

        // temprow has the old style low to high level categories.
        $newlevel = 1;
        // let's turn them into high to low level categories
        for( $categorylevel = EP_MAX_CATEGORIES; $categorylevel>0; $categorylevel--) {
            $found = false;
            if ($temprow['v_categories_image_' . $categorylevel] != ''){
                $row['v_categories_image_' . $newlevel] = $temprow['v_categories_image_' . $categorylevel];
                $found = true;
            }
            foreach ($languages as $key => $lang){
                if ($temprow['v_categories_name_' . $categorylevel . '_' . $lang['id']] != ''){
                    $row['v_categories_name_' . $newlevel . '_' . $lang['id']] = $temprow['v_categories_name_' . $categorylevel . '_' . $lang['id']];
                    $found = true;
                }
            }
            if ($found == true) {
                $newlevel++;
            }
        }

        // if the filelayout says we need a manufacturers name, get it
        if (isset($filelayout['v_manufacturers_name'])){
            if ($row['v_manufacturers_id'] != ''){
                $sql2 = "SELECT manufacturers_name
                    FROM manufacturers
                    WHERE
                    manufacturers_id = " . $row['v_manufacturers_id'];
                $result2 = tep_db_query($sql2);
                $row2 =  tep_db_fetch_array($result2);
                $row['v_manufacturers_name'] = ($row2['manufacturers_name'] ?? '');
            }
        }

        // If you have other modules that need to be available, put them here

        // VJ product attribs begin
        if (isset($filelayout['v_attribute_options_id_1'])){

            $attribute_options_count = 1;
            foreach ($attribute_options_array as $attribute_options) {
                $row['v_attribute_options_id_' . $attribute_options_count]     = $attribute_options['products_options_id'];

                for ($i=0, $n=sizeof($languages); $i<$n; $i++) {
                    $lid = $languages[$i]['id'];
                    $attribute_options_languages_query = "select products_options_name from products_options where products_options_id = '" . (int)$attribute_options['products_options_id'] . "' and language_id = '" . (int)$lid . "'";
                    $attribute_options_languages_values = tep_db_query($attribute_options_languages_query);
                    $attribute_options_languages = tep_db_fetch_array($attribute_options_languages_values);
                    $row['v_attribute_options_name_' . $attribute_options_count . '_' . $lid] = $attribute_options_languages['products_options_name'];
                }

                $attribute_values_query = "select products_options_values_id from products_options_values_to_products_options where products_options_id = '" . (int)$attribute_options['products_options_id'] . "' order by products_options_values_id";
                $attribute_values_values = tep_db_query($attribute_values_query);
                $attribute_values_count = 1;
                
                while ($attribute_values = tep_db_fetch_array($attribute_values_values)) {
                    $row['v_attribute_values_id_' . $attribute_options_count . '_' . $attribute_values_count]     = $attribute_values['products_options_values_id'];
                    $attribute_values_price_query = "select options_values_price, price_prefix from products_attributes where products_id = '" . (int)$row['v_products_id'] . "' and options_id = '" . (int)$attribute_options['products_options_id'] . "' and options_values_id = '" . (int)$attribute_values['products_options_values_id'] . "'";
                    $attribute_values_price_values = tep_db_query($attribute_values_price_query);
                    if (tep_db_num_rows($attribute_values_price_values)) {
                        $attribute_values_price = tep_db_fetch_array($attribute_values_price_values);
                        $row['v_attribute_values_price_' . $attribute_options_count . '_' . $attribute_values_count] = $attribute_values_price['price_prefix'] . $attribute_values_price['options_values_price'];
                    }
                    
                    //// attributes stock add start        
                    if ( EP_PRODUCTS_ATTRIBUTES_STOCK == true ) {   
                           $stock_attributes = $attribute_options['products_options_id'].'-'.$attribute_values['products_options_values_id'];
                           $stock_quantity_query = tep_db_query("select products_stock_quantity from products_stock where products_id = '" . (int)$row['v_products_id'] . "' and products_stock_attributes = '" . $stock_attributes . "'");
                           $stock_quantity = tep_db_fetch_array($stock_quantity_query);
                           $row['v_attribute_values_stock_' . $attribute_options_count . '_' . $attribute_values_count] = $stock_quantity['products_stock_quantity'];
                    }
                    //// attributes stock add end  
                                       
                    for ($i=0, $n=sizeof($languages); $i<$n; $i++) {
                        $lid = $languages[$i]['id'];
                        $attribute_values_languages_query = "select products_options_values_name from products_options_values where products_options_values_id = '" . (int)$attribute_values['products_options_values_id'] . "' and language_id = '" . (int)$lid . "'";
                        $attribute_values_languages_values = tep_db_query($attribute_values_languages_query);
                        $attribute_values_languages = tep_db_fetch_array($attribute_values_languages_values);
                        $row['v_attribute_values_name_' . $attribute_options_count . '_' . $attribute_values_count . '_' . $lid] = $attribute_values_languages['products_options_values_name'];
                    }
                    $attribute_values_count++;
                }
                $attribute_options_count++;
            }
        }
        // VJ product attribs end

        // this is for the cross sell contribution
        if (isset($filelayout['v_cross_sell'])){
            $px_models = '';
            $sql2 = "SELECT
                             px.products_id,
                             px.xsell_id,
              p.products_model
                         FROM
                             products_xsell px, 
              products p
                         WHERE
                         px.xsell_id = p.products_id and 
                         px.products_id = " . $row['v_products_id'] . "
                         ";
            $cross_sell_result = tep_db_query($sql2);
            while( $cross_sell_row = tep_db_fetch_array($cross_sell_result) ){
                $px_models .= $cross_sell_row['products_model'] . ',';
            }
            if (strlen($px_models) > 0) { 
                $px_models = substr($px_models, 0, -1); 
            }
            $row['v_cross_sell'] = $px_models;
        }

        // this is for the separate price per customer module
        if (isset($filelayout['v_customer_price_1'])){
            $sql2 = "SELECT
                    customers_group_price,
                    customers_group_id
                FROM
                    products_groups
                WHERE
                products_id = " . $row['v_products_id'] . "
                ORDER BY
                customers_group_id"
                ;
            $result2 = tep_db_query($sql2);
            $ll = 1;
            $row2 =  tep_db_fetch_array($result2);
	    
            // do pricing specials
            if (isset($filelayout['v_customer_specials_price_1'])){
              $sppc_specials = array();
              $specials_result = tep_db_query("SELECT specials_new_products_price, status, customers_group_id FROM specials WHERE products_id = " . $row['v_products_id'] . " and customers_group_id <> 0 and expires_date < CURRENT_TIMESTAMP ORDER BY specials_id DESC");
              while( $specials_result_row = tep_db_fetch_array($specials_result) ){
                $sppc_specials[$specials_result_row['customers_group_id']] = $specials_result_row['specials_new_products_price'];
              }
            }
			
            while( $row2 ){
                $row['v_customer_group_id_' . $ll]     = $row2['customers_group_id'];
                $row['v_customer_price_' . $ll]     = $row2['customers_group_price'];
                // do pricing specials
                if (isset($filelayout['v_customer_specials_price_1'])){
                  $row['v_customer_specials_price_' . $ll]     = $sppc_specials[$ll];
                }
                $row2 = tep_db_fetch_array($result2);
                $ll++;
            }
            // do pricing specials
            $specials_result = tep_db_query("SELECT specials_new_products_price, status FROM specials WHERE products_id = " . $row['v_products_id'] . " and customers_group_id <> 0 and expires_date < CURRENT_TIMESTAMP ORDER BY specials_id DESC");
            if( $specials_result_row = tep_db_fetch_array($specials_result) ){
              if ($specials_result_row['status'] == 1) {
                $row['v_products_specials_price']     = $specials_result_row['specials_new_products_price'];
              } else {
                $row['v_products_specials_price']     = $specials_result_row['specials_new_products_price'];
              }
            } else {
              $row['v_products_specials_price']     = '';
            }
        }

        if (isset($dltype) && $dltype == 'google_shopping'){
            // For google_shopping, we check the specials prices for any applicable specials, and use that price
            // by grabbing the specials id descending, we always get the most recently added special price
            // I'm checking status because I think you can turn off specials
            $sql2 = "SELECT
                    specials_new_products_price
                FROM
                    specials
                WHERE
                products_id = " . $row['v_products_id'] . " and
                status = 1 and
                expires_date < CURRENT_TIMESTAMP
                ORDER BY specials_id DESC";
            $result2 = tep_db_query($sql2);
            $ll = 1;
            $row2 =  tep_db_fetch_array($result2);
            if( $row2 ){
                // reset the products price to our special price if there is one for this product
                $row['v_products_price']     = $row2['specials_new_products_price'];
            }
        }

        //elari -
        //We check the value of tax class and title instead of the id
        //Then we add the tax to price if EP_PRICE_WITH_TAX is set to true
        $row_tax_multiplier         = (isset($row['v_tax_class_id']) ? tep_get_tax_class_rate($row['v_tax_class_id']) : 1);
        $row['v_tax_class_title']   = (isset($row['v_tax_class_id']) ? tep_get_tax_class_title($row['v_tax_class_id']) : '');
        
        if (isset($row['v_products_price'])) {
        $row['v_products_price']  = $row['v_products_price'] +
                (EP_PRICE_WITH_TAX == true ? round( ($row['v_products_price'] * $row_tax_multiplier / 100), EP_PRECISION) : 0);
        }
        
        // do pricing specials
        
        $SPPC_extra_query = ($options_array['option_sppc'] ? ' and customers_group_id = 0 ' : '');
        
        if (isset($filelayout['v_products_specials_price'])){
            $specials_result = tep_db_query("SELECT specials_new_products_price, status FROM specials WHERE products_id = " . (int)$row['v_products_id'] . " " . $SPPC_extra_query . "and (expires_date < CURRENT_TIMESTAMP or expires_date is null) ORDER BY specials_id DESC");
            if( $specials_result_row = tep_db_fetch_array($specials_result) ){
                if ($specials_result_row['status'] == 1) {
                    $row['v_products_specials_price']     = $specials_result_row['specials_new_products_price'];
                } else {
                    $row['v_products_specials_price']     = $specials_result_row['specials_new_products_price'];
                }
            } else {
                $row['v_products_specials_price']     = '';
            }
        }

        // Now set the status to a word the user specd in the config vars
        $row['v_status'] = (( isset($row['v_status']) && $row['v_status'] == '1' ) ? EP_TEXT_ACTIVE : EP_TEXT_INACTIVE );

        // remove any bad things in the texts that could confuse EasyPopulate
        $therow = '';
        
        foreach( $filelayout as $key => $value ) {
            //echo "The field was $key<br />";

            $thetext = (isset($row[$key]) ? $row[$key] : ''); 
            //$thetext = '"'.str_replace('&#44;', ' ', $thetext) .'"'; 
          //  $thetext = str_replace('&#44;', ' ', $thetext); 

            // kill the carriage returns and tabs in the descriptions, they're killing me!
            if (EP_PRESERVE_TABS_CR_LF == false || $dltype == 'google_shopping') {
                 $thetext = str_replace(["\r", "\n", "\t"], ' ', $thetext);
            }
            
            if (EP_EXCEL_SAFE_OUTPUT == true && isset($dltype) && $dltype != 'google_shopping') {
                 // use quoted values and escape the embedded quotes for excel safe output.
                 $therow .= '"'.str_replace('"','""',$thetext).'"' . $ep_separator;
            } else {
                 // and put the text into the output separated by $ep_separator defined above
                 $therow .= $thetext . $ep_separator;
            }
        }

        // lop off the trailing separator, then append the end of row indicator
        $therow = substr($therow,0,strlen($therow)-1) . $endofrow;

        if ($_GET['download'] == 'activestream'){
            //echo $therow;  //display in popup or write to file
            echo $therow;  //display in popup or write to file
        } else {
            $filestring .= $therow;
        }
        // grab the next row from the db
        $row =  tep_db_fetch_array($result);
    }

    // now either stream it to them or put it in the temp directory
    if ($_GET['download'] == 'activestream'){
        die();
    } elseif ($_GET['download'] == 'stream'){
        //*******************************
        // STREAM FILE
        //*******************************
        //		header('Content-Transfer-Encoding: none');
        if (EP_EXCEL_SAFE_OUTPUT == true) {
          header("Content-type: text/x-csv");
      //		header('Content-type: text/x-csv; charset="utf-8"');
      //		header("Content-type: application/vnd.ms-excel");
      //		header('Content-type: application/vnd.ms-excel; charset="utf-8"');
        } else {
        header("Content-type: text/plain");
        }
        header("Content-disposition: attachment; filename=$EXPORT_TIME" . ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"));
        // Changed if using SSL, helps prevent program delay/timeout (add to backup.php also)
        if ($request_type== 'NONSSL'){
            header("Pragma: no-cache");
        } else {
            header("Pragma: ");
        }
        header("Expires: 0");
        echo $filestring;
        die();
    } elseif ($_GET['download'] == 'tempfile') {
        //*******************************
        // PUT FILE IN TEMP DIR
        //*******************************
        $tmpfname = EP_TEMP_DIRECTORY . "$EXPORT_TIME" . ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt");
        //unlink($tmpfname);
        $fp = @fopen( $tmpfname, "w+");
        if ($fp) {
            fwrite($fp, $filestring);
            fclose($fp);
            $msgArray['msg'] = "You can get your file in the Tools/File Manager here: " . EP_TEMP_DIRECTORY . "EP" . $EXPORT_TIME . ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt");
        } else {
            $msgArray = sprintf(FAILURE_OPEN_OUTPUT, $tmpfname);
        } 
    }
} 

//*******************************
//*******************************
// S T A R T
// PAGE DELIVERY
//*******************************
//*******************************
  require('includes/template_top.php');
?>


<td class="pageHeading" valign="top">
  <table border="0" width="100%" cellspacing="0" cellpadding="0">
   <tr>
     <td class="display-4"><?php echo "Easy Populate ".EP_CURRENT_VERSION; ?> 
     <span class="h4 text-danger"><?php echo (function_exists('UploadImages') ? EP_VERSION_TYPE[1] : EP_VERSION_TYPE['0']); ?></span>
     </td>
   </tr>
   <tr>
    <td><table width="100%">
     <tr>
      <td><?php echo EP_SUPPORT_THREAD; ?></td>
      <td style="background-color:#FFFFCC;">
            Please <a href="<?php echo tep_href_link('backup.php'); ?>"><span style="text-decoration:underline;">backup your database</span></a> before performing any Easy Populate operations!
      </td>
     </tr>
    </table></td>     
   </tr>       

   <tr><td>
   <?php echo DisplayMsg($msgArray); ?>   
   </td></tr>
 </table>         

<p class=""><?php

//*******************************
//*******************************
// UPLOAD AND INSERT FILE
//*******************************
//*******************************
if (!empty($_POST['localfile']) || (isset($_FILES['usrfl']) && isset($_GET['split']) && $_GET['split']==0)) {

    if (isset($_FILES['usrfl'])){
        // move the file to where we can work with it
        $file = tep_get_uploaded_file('usrfl');
        if (is_uploaded_file($file['tmp_name'])) {
            tep_copy_uploaded_file($file, EP_TEMP_DIRECTORY);
        }

        echo '<p class="bg-success text-white pl-1 border border-dark">';
        echo "File uploaded. <br />";
        echo "Temporary filename: " . $file['tmp_name'] . "<br />";
        echo "User filename: " . $file['name'] . "<br />";
        echo "Size: " . $file['size'] . "<br />";

        // get the entire file into an array
        $readed = file(EP_TEMP_DIRECTORY . $file['name']);
    }
    if (!empty($_POST['localfile'])){
        // move the file to where we can work with it
        //$file = tep_get_uploaded_file('usrfl');

        //$attribute_options_query = "select distinct products_options_id from products_options order by products_options_id";
        //$attribute_options_values = tep_db_query($attribute_options_query);
        //$attribute_options_count = 1;
        //while ($attribute_options = tep_db_fetch_array($attribute_options_values)){

        //if (is_uploaded_file($file['tmp_name'])) {
        //    tep_copy_uploaded_file($file, EP_TEMP_DIRECTORY);
        //}

        echo "<p class=>";
        echo "Filename: " . $_POST['localfile'] . "<br />";

        // get the entire file into an array
        $readed = file(EP_TEMP_DIRECTORY . $_POST['localfile']);
    }
    
    if (EP_EXCEL_SAFE_OUTPUT == true) {
    
        // do excel safe input
        $fp = @fopen(EP_TEMP_DIRECTORY . (isset($_FILES['usrfl'])?$file['name']:$_POST['localfile']),'r') or die('##Can not open file for reading. Script will terminate.<br />');  // open file
        // determine the separator character.
        $header_line = fgets($fp);
        if (strpos($header_line,',') !== false)  { $ep_separator = ','; }
        if (strpos($header_line,';') !== false)  { $ep_separator = ';'; }
        if (strpos($header_line,"\t") !== false) { $ep_separator = "\t"; }
        if (strpos($header_line,'~') !== false)  { $ep_separator = '~'; }
        if (strpos($header_line,'-') !== false)  { $ep_separator = '-'; }
        if (strpos($header_line,'*') !== false)  { $ep_separator = '*'; }
        fclose($fp); 

        if (EP_EXCEL_SAFE_OUTPUT_ALT_PARCE == false) {
            
            unset($readed);                    // kill array setup with above code
            $readed = array();                 // start a new one for excel_safe_output
            $fp = @fopen(EP_TEMP_DIRECTORY . (isset($_FILES['usrfl'])?$file['name']:$_POST['localfile']),'r') or die('##Can not open file for reading. Script will terminate.<br />');  // open file
            while($line = fgetcsv ($fp,32768,$ep_separator)) {  // read new line (max 32K bytes)
                unset($line[(sizeof($line)-1)]);  // remove EOREOR at the end of the array
                $readed[] = $line;                // add to array we will process later
            }
            $theheaders_array = $readed[0];     // pull out header line
            fclose($fp);                        // close file

        } else {
        
            // Maynard's CSV Fix ###################################################
            // some versions of fgetcsv don't like a field beginning with "", so we'll parse it ourselves
            // use readed, but parse it ourselves according to $ep_separator, and " as field encloser
            
            // I copied this from below:
            // now we string the entire thing together in case there were carriage returns in the data
              $newreaded = "";
              foreach ($readed as $read){
                $newreaded .= $read;
              }
              // now newreaded has the entire file together without the carriage returns.
              // if for some reason excel put qoutes around our EOREOR, remove them then split into rows
              $newreaded = str_replace('"EOREOR"', 'EOREOR', $newreaded);
              $readed = explode( $ep_separator . 'EOREOR',$newreaded);
            // dump the last entry - it's blank
            unset($readed[sizeof($readed)-1]);    
            // parse it all!
            foreach ($readed as $key => $line) {
                $ppp = 0; // pointer
                $line1 = array();
                $remains = trim($line);
                while ($remains != '') {
                    if (substr($remains,0,1) == '"') {
                        // this is an enclosed portion
                        $ppp1 = -1; // so that our first loop points to the right place in $remains
                        $ppp2 = -1;
                        // we've got to find the next " that isn't ""    
                        while($ppp1 < strlen($remains) && $ppp1 == $ppp2 && $ppp1 !== FALSE) {
                            $ppp1 = strpos($remains, '"', $ppp2+2);
                            $ppp2 = strpos($remains, '""', $ppp2+2); // use ppp2 because then """ will get properly understood                
                        }
                        // now $ppp1 points to the closing "
                        // we are pulling out the determined chunk and 
                        // replacing any double quotes with single quotes 
                        // since that is how CSV handles quotes
                        $line1[] = str_replace('""','"',substr($remains,1,$ppp1-1));
                        // find the next separator - for a well formed CSV file, it MUST be a separator (and not in quoted text)
                        $ppp1 = strpos($remains, $ep_separator, $ppp1);
                        $remains = ($ppp1 !== false) ? substr($remains,$ppp1+1) : '';             
                    } else {
                        // this is an un-enclosed portion - find the next separator
                        $ppp1 = strpos($remains, $ep_separator, 0);
                        $line1[] = ($ppp1 !== false) ? substr($remains,0,$ppp1) : $remains;
                        $remains = ($ppp1 !== false) ? substr($remains,$ppp1+1) : '';                        
                    }
                }
                // replace that line with our new array
                $readed[$key] = $line1;
            }
            $theheaders_array = $readed[0];     // pull out header line    
            // EOF Maynard's CSV Fix ###################################################      
        }

    } else {
        // do normal EP input
        // now we string the entire thing together in case there were carriage returns in the data
        $newreaded = "";
        foreach ($readed as $read){
            $newreaded .= $read;
        }

        // now newreaded has the entire file together without the carriage returns.
        // if for some reason excel put qoutes around our EOREOR, remove them then split into rows
        $newreaded = str_replace('"EOREOR"', 'EOREOR', $newreaded);
        $readed = explode( $ep_separator . 'EOREOR',$newreaded);

        // Now we'll populate the filelayout based on the header row.
        $theheaders_array = explode( $ep_separator, $readed[0] ); // explode the first row, it will be our filelayout
    }
    
    $lll = 0;
    $filelayout = array();
    foreach( $theheaders_array as $header ){
        $cleanheader = str_replace( '"', '', $header);
        // echo "Fileheader was $header<br /><br /><br />";
        $filelayout[ $cleanheader ] = $lll++; //
    }
    unset($readed[0]); //  we don't want to process the headers with the data

    // now we've got the array broken into parts by the expicit end-of-row marker.
    foreach ($readed as $tkey => $readed_row) {
        process_row($readed_row, $filelayout, $filelayout_count, $default_these, $ep_separator, $languages, $custom_fields);
    }
    // isn't working in PHP 5
    // array_walk($readed, $filelayout, $filelayout_count, $default_these, 'process_row');


//*******************************
//*******************************
// UPLOAD AND SPLIT FILE
//*******************************
//*******************************
} elseif (isset($_FILES['usrfl']) && isset($_GET['split']) && $_GET['split']==1) {
    // move the file to where we can work with it
    $file = tep_get_uploaded_file('usrfl');
    //echo "Trying to move file...";
    if (is_uploaded_file($file['tmp_name'])) {
        tep_copy_uploaded_file($file, EP_TEMP_DIRECTORY);
    }

    $infp = @fopen(EP_TEMP_DIRECTORY . $file['name'], "r");
    if ($infp) {
        $ext_tmp = substr( $file['name'], -3 , 3 );
     
        //toprow has the field headers
        $toprow = fgets($infp,32768);
        $filecount = 1;

        $msgArray['msg'] = 'Creating file EP_Split' . $filecount . '.'.$ext_tmp.' ... <br>';
        $tmpfname = EP_TEMP_DIRECTORY . "EP_Split" . $filecount.'.'.$ext_tmp;
        $fp = @fopen( $tmpfname, "w+");
        if ($fp) {
            fwrite($fp, $toprow);

            $linecount = 0;
            $line = fgets($infp,32768);
            while ($line){
                // walking the entire file one row at a time
                // but a line is not necessarily a complete row, we need to split on rows that have "EOREOR" at the end
                $line = str_replace('"EOREOR"', 'EOREOR', $line);
                fwrite($fp, $line);
                if (strpos($line, 'EOREOR')){
                    // we found the end of a line of data, store it
                    $linecount++; // increment our line counter
                    if ($linecount >= EP_SPLIT_MAX_RECORDS){
                        $msgArray['msg'] .= "Added $linecount records and closing file... <br />";
                        $linecount = 0; // reset our line counter
                        // close the existing file and open another;
                        fclose($fp);
                        // increment filecount
                        $filecount++;
                        $msgArray['msg'] .= "Creating file EP_Split" . $filecount . '.'.$ext_tmp.' ...  ';
                        $tmpfname = EP_TEMP_DIRECTORY . "EP_Split" . $filecount.'.'.$ext_tmp;
                        //Open next file name
                        $fp = fopen( $tmpfname, "w+");
                        fwrite($fp, $toprow);
                    }
                }
                $line=fgets($infp,32768);
            }
            $msgArray['msg'] .= "Added $linecount records and closing file...<br /><br /> ";
            fclose($fp);
        } else {
            $msgArray['msg'] .= sprintf(FAILURE_OPEN_OUTPUT, $tmpfname);
        }            
        fclose($infp);
    } else {
        $msgArray['msg'] .= sprintf(FAILURE_OPEN_INPUT, EP_TEMP_DIRECTORY . $file['name']);
    }   

    $msgArray['msg'] .= "You can download your split files in the Tools/Files under " . EP_TEMP_DIRECTORY;
    echo DisplayMsg($msgArray);     
}

//*******************************
//*******************************
// MAIN MENU
//*******************************
//*******************************
?>
      </p>

      <table border="2" width="<?php if (EP_SHOW_EP_SETTINGS == true) { echo '95'; } else { echo '75'; } ?>%" cellpadding="5" cellspacing="0" style="border-collapse:collapse;">
        <tr>
          <td width="75%" style="vertical-align:top;border-style:solid; border-width:thin; border-color:#CCCCCC;">
             <form enctype="multipart/form-data" action="easypopulate.php?split=0<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>" method="post"><?php if (defined('SID') && tep_not_null(SID)) { echo tep_draw_hidden_field(tep_session_name(), tep_session_id()); } ?>
                <div class="border border-dark pb-3 bg-light font-weight-bold mt-1 mb-0"><?php echo TITLE_UPLOAD_IMPORT; ?>
                 <div class="pt-2 pl-2">
                  <input type="hidden" name="MAX_FILE_SIZE" value="100000000">
                  <input name="usrfl" type="file" size="50">
                  <select name="imput_mode">
                      <option value="normal">Normal</option>
                      <option value="addnew">Add New Only</option>
                      <option value="update">Update Only</option>
                  </select>
                  <input type="submit" name="buttoninsert" value="Insert into db">
                 </div>
                </div>
             </form>

             <form enctype="multipart/form-data" action="easypopulate.php?split=1<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>" method="post"><?php if (defined('SID') && tep_not_null(SID)) { echo tep_draw_hidden_field(tep_session_name(), tep_session_id()); } ?>
                <div class="border border-dark pb-3 bg-light font-weight-bold mt-1 mb-0"><?php echo TITLE_UPLOAD_SPLIT; ?>
                 <div class="pt-2 pl-2">                
                   <input type="hidden" name="MAX_FILE_SIZE" value="1000000000">
                   <input name="usrfl" type="file" size="50">
                  <input type="submit" name="buttonsplit" value="Split file">
                 </div>
                </div>
             </form>

             <form enctype="multipart/form-data" action="easypopulate.php<?php if (defined('SID') && tep_not_null(SID)) { echo '?'.tep_session_name().'='.tep_session_id(); } ?>" method="post"><?php if (defined('SID') && tep_not_null(SID)) { echo tep_draw_hidden_field(tep_session_name(), tep_session_id()); } ?>
                <div class="border border-dark pb-3 bg-light font-weight-bold mt-1 mb-0"><?php echo TITLE_IMPORT_FILE_FROM_TEMP; ?>
                 <div class="pt-2 pl-2">                
                  <?PHP
                    //<input type="text" name="localfile" size="50">
                    $the_array = [];
                    if (is_readable(EP_TEMP_DIRECTORY)) {
                        $handle = opendir(EP_TEMP_DIRECTORY);
                        while (false!== ($file = readdir($handle))) {
                          if ($file!= "." && $file!= ".." &&!is_dir($file)) {
                              $namearr = preg_split('/\./',$file);
                              if ($namearr[count($namearr)-1] == 'csv' || $namearr[count($namearr)-1] == 'txt') $the_array[] = $file;
                          }
                        }
                        closedir($handle);
                    }
                        
                    $array_size = count($the_array);
                    if($array_size == 0){
                        echo ('            <input type="text" name="localfile" size="50">' . "\n");
                    } else {
                        echo ('            <select name="localfile" size="1">' . "\n");
                        foreach ($the_array as $list){
                           echo ('                <option value="' . $list . '">' . $list . '</option>' . "\n");
                        }
                        echo ('            </select>' . "\n");
                    }
                    ?>
                  <select name="imput_mode">
                      <option value="normal">Normal</option>
                      <option value="addnew">Add New Only</option>
                      <option value="update">Update Only</option>
                  </select>
                  <input type="submit" name="buttoninsert" value="Insert into db">
                 </div>
                </div>
             </form>

             <div class="border border-dark pb-3 bg-light font-weight-bold mt-1 mb-0"><?php echo TITLE_EXPORT_FILE; ?>
               <div class="pt-2 pl-2">               
             
               <!-- Download file links -  Add your custom fields here -->
               <table border="0" cellpadding="0" cellspacing="0" class="">
               <?php echo tep_draw_form('custom', 'easypopulate.php', ((defined('SID') && tep_not_null(SID)) ? tep_session_name().'='.tep_session_id() : ''), 'get','id="custom"'); ?><?php if (defined('SID') && tep_not_null(SID)) { echo tep_draw_hidden_field(tep_session_name(), tep_session_id()); } ?>
               
               <tr>
                 <td colspan="3"><table border="0" width="100%" cellpadding="0" cellspacing="0" style=""><tr>
                 <td class="" style="width:50%;">
                 <?php echo tep_draw_pull_down_menu('download',array( 0 => array( "id" => 'activestream', 'text' => 'Download on-the-fly' ), 1 => array( "id" => 'stream', 'text' => 'Create then Download' ), 2 => array( "id" => 'tempfile', 'text' => 'Create in Temp Dir' )), '', ' '); ?>
                 </td><td class="" style="width:50%;">
                 <?php echo tep_draw_pull_down_menu('dltype',array( 0 => array( "id" => 'full', 'text' => 'Complete' ), 1 => array( "id" => 'custom', 'text' => 'Custom' ), 2 => array( "id" => 'priceqty', 'text' => 'Price/Qty' ), 3 => array( "id" => 'category', 'text' => 'Categories' ), 4 => array( "id" => 'attrib', 'text' => 'Attributes' ), 5 => array( "id" => 'google_shopping', 'text' => 'Google Shopping' )),'custom','onChange="return switchForm(this);" id="filterDropDown" '); ?>          
                 </td>
                 </tr></table></td>
               </tr>
               
               <tr><td class="" colspan="7" style="font-weight:bold;">
               <?php echo ((EP_EXCEL_SAFE_OUTPUT == true) ? ".csv" : ".txt") . ' file (model number is always included).'; ?>          
               </td></tr>
               
               <?php                    
               $cells = array();
               $cells[0][] = DisplayCell('epcust_name', 'name');
               $cells[0][] = DisplayCell('epcust_description', 'description');
               $cells[0][] = DisplayCell('epcust_url', 'url');
               $cells[0][] = DisplayCell('epcust_image', 'image');
               
               if (EP_PRODUCTS_WITH_ATTRIBUTES == true) {
                   $cells[0][] = DisplayCell('epcust_attributes', 'attributes');
               }

               $cells[0][] = DisplayCell('epcust_category', 'category');
               $cells[0][] = DisplayCell('epcust_manufacturer', 'manufacturer');

               $cells[1][] = DisplayCell('epcust_price', 'price');
               $cells[1][] = DisplayCell('epcust_quantity', 'quantity');
               $cells[1][] = DisplayCell('epcust_weight', 'weight');
               $cells[1][] = DisplayCell('epcust_tax_class', 'tax_class');
               $cells[1][] = DisplayCell('epcust_date_avail', 'available');
               $cells[1][] = DisplayCell('epcust_date_added', 'date added');
               $cells[1][] = DisplayCell('epcust_status', 'status');
      
               $tmp_row_count = 2;
               $tmp_col_count = 0;
               $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_specials', 'specials');
               
               // results displaying
               if ($options_array['option_product_images']) {
                   $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_prod_images', 'add images');
               }
               if ($options_array['option_quantity_prices']) {
                   $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_qpbp', 'add qpbp');
               }
               
               if ($options_array['option_mvs']) { 
                   $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_prod_vendor', 'vendor');
               }
               if ($options_array['option_xsell']) { 
                   $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_cross sell', 'x-sell');
               }
               if ($options_array['option_master_products']) { 
                   $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_cross products_master', 'master'); 
                   $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_cross products_master_status', 'master status');
                   $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_cross products_model_id', 'prod-id'); 
               }
            
               $bigbox = new epbox('',false);
               $bigbox->table_parameters = 'id="customtable" style="border: 1px solid #ccc; padding: 2px; margin: 3px;"';
               echo $bigbox->output($cells);
            
               foreach ($custom_fields['products'] as $key => $name) { 
                   $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_' . $key, $name);    
                   if ($tmp_col_count >= 7) { 
                       $tmp_row_count += 1; 
                       $tmp_col_count = 0; 
                   }
               }

               foreach ($custom_fields['products_description'] as $key => $name) { 
                   $cells[$tmp_row_count][$tmp_col_count++] = DisplayCell('epcust_' . $key, $name); 
                   if ($tmp_col_count >= 7) { 
                       $tmp_row_count += 1; 
                       $tmp_col_count = 0; 
                   }
               }

               $manufacturers_array = array();
               $manufacturers_array[] = array( "id" => '', 'text' => '- manufacturer -' );
               $manufacturers_query = tep_db_query("select manufacturers_id, manufacturers_name from manufacturers order by manufacturers_name");
               while ($manufacturers = tep_db_fetch_array($manufacturers_query)) {
                   $manufacturers_array[] = array( "id" => $manufacturers['manufacturers_id'], 'text' => $manufacturers['manufacturers_name'] );
               }

               $status_array = array(array( "id" => '', 'text' => '- status -' ),array( "id" => '1', 'text' => 'active' ),array( "id" => '0', 'text' => 'disabled' ));

               ?>
               <tr>
                 <td colspan="3"><table border="0" width="100%" cellpadding="0" cellspacing="0" style=""><tr>
                   <td style="font-weight:bold;">Filter By</td>
                   <tr>
                   <td class="">
                   <?php echo   tep_draw_pull_down_menu('epcust_category_filter', array_merge(array( 0 => array( "id" => '', 'text' => '- category -' )), tep_get_category_tree())); ?>
                   </td><td class="">
                   <?php echo tep_draw_pull_down_menu('epcust_manufacturer_filter', $manufacturers_array); ?>
                   </td><td class="">
                   <?php echo tep_draw_pull_down_menu('epcust_status_filter', $status_array); ?>
                   </td>
                 </tr></table></td>
               </tr>
               <?php  
                         
               ?><tr><td colspan="7" class="pt-1"><?php
          echo tep_draw_input_field('submit', 'Build File', ' style="padding: 0px"', false, 'submit');
               ?></td></tr>
               </form>
               </table>     
              </div>
             </div>

              <div class="border border-dark pb-2 bg-light font-weight-bold mt-1 mb-0"><?php echo TITLE_QUICK_LINKS; ?>
               <div class="pt-2 pl-2">                
              <table width="100%" border="0" cellpadding="3" cellspacing="3">
               <tr>
                 <td width="50%" valign="top" bgcolor="#EEEEEE">
                    <p style="margin-top:8px;"><b>Create then Download Files</b><br />
                    <font size="-2">Create entire file in server memory then stream download after completed.</font></p>
                    <p><!-- Download file links -  Add your custom fields here -->
                      <a href="easypopulate.php?download=stream&dltype=google_shopping<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Basic</b> csv file to edit</a><br />
                      <a href="easypopulate.php?download=stream&dltype=full<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Complete<?php if ($options_array['option_sppc']) { echo ' w/SPPC'; } ?></b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file to edit</a><br />
                      <?php if ($options_array['option_extra_fields']) { ?>
                      <a href="easypopulate.php?download=stream&dltype=extra_fields<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Extra Fields</b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file to edit</a><br />
                      <?php } ?>
                      <a href="easypopulate.php?download=stream&dltype=priceqty<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Price/Qty<?php if ($options_array['option_sppc']) { echo ' w/SPPC'; } ?></b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file to edit</a><br />
                      <a href="easypopulate.php?download=stream&dltype=category<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Category</b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file to edit</a><br />
                      <!-- Products Images Support //-->
                      <a href="easypopulate.php?download=stream&dltype=prodimage<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Images<?php if ($options_array['option_sppc']) { echo ' w/SPPC'; } ?></b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file to edit</a><br />
                      <!-- Products Images Support end //-->
                      <!-- VJ product attributes begin //-->
                      <?php if (EP_PRODUCTS_WITH_ATTRIBUTES == true) { ?>
                      <a href="easypopulate.php?download=stream&dltype=attrib<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Attributes</b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file</a><br />
                      <?php } ?>
                      <!-- VJ product attributes end //-->
                      <!-- Master Products support begin //-->
                      <?php if ($options_array['option_master_products']) { ?>
                      <a href="easypopulate.php?download=stream&dltype=masterstatus<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Master/Status<?php if ($options_array['option_sppc']) { echo ' w/SPPC'; } ?></b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file to edit</a><br />
                      <?php } ?>
                      <!-- Master Products support end //-->
                    </p>
                </td>
                <td width="50%" valign="top" bgcolor="#EEEEEE">
                  <p style="margin-top:8px;"><b>Create Files in Temp Dir</b><br />
                  <font size="-2">Create entire file in server memory then save to Temp Dir after completed.</font></p>
                  <p>
                    <a href="easypopulate.php?download=tempfile&dltype=google_shopping<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Basic</b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file in temp dir</a><br />        
                    <a href="easypopulate.php?download=tempfile&dltype=full<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Complete</b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file in temp dir</a><br />
                    <a href="easypopulate.php?download=tempfile&dltype=priceqty<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Price/Qty</b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file in temp dir</a><br />
                    <a href="easypopulate.php?download=tempfile&dltype=category<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Category</b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file in temp dir</a><br />
                    <!-- Products Images Support //-->
                    <a href="easypopulate.php?download=tempfile&dltype=prodimage<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Images</b><?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file in temp dir</a><br />
                    <!-- Products Images Support end //-->
                    <!-- VJ product attributes begin //-->
                    <?php if (EP_PRODUCTS_WITH_ATTRIBUTES == true) { ?>
                    <a href="easypopulate.php?download=tempfile&dltype=attrib<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Attributes</b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file in temp dir</a><br />
                    <?php } ?>
                    <!-- VJ product attributes end //-->
                    <!-- Master Products support begin //-->
                    <?php if ($options_array['option_master_products']) { ?>
                    <a href="easypopulate.php?download=tempfile&dltype=masterstatus<?php if (defined('SID') && tep_not_null(SID)) { echo '&'.tep_session_name().'='.tep_session_id(); } ?>"><b>Model/Master/Status</b> <?php echo ((EP_EXCEL_SAFE_OUTPUT == true)?".csv":".txt"); ?> file in temp dir</a><br />
                    <?php } ?>
                    <!-- Master Products support end //-->
                  </p>
                </td>
               </tr>
              </table>
             </div>
            </div>             
        
            <div class="border border-dark pb-3 bg-light font-weight-bold mt-1 mb-0"><?php echo TITLE_ADDITIONAL_OPTIONS; ?>
             <div class="pt-2 pl-2">              
              <table width="100%" border="0" cellpadding="3" cellspacing="3">
                <tr>
                  <td width="100%" valign="top" bgcolor="#EEEEEE">
                   <div id="check-image-usage" class="text-primary font-weight-bold"><?php echo TEXT_CHECK_IMAGE_USAGE; ?><span id="check-image-usage-success" class="ml-4 text-success font-weight-bold"></span></div>
                  </td>
                </tr>
                
                <tr>
                  <td width="100%" valign="top" bgcolor="#EEEEEE">                  
                   <div id="clear-temp-dir" class="text-primary font-weight-bold"><?php echo TEXT_CLEAR_TEMP; ?><span id="clear-success" class="ml-4 text-success font-weight-bold"></span></div>
                  </td>
                </tr>

                <tr>
                 <td>
                  <form enctype="multipart/form-data" action="easypopulate.php" method="POST">
                   <div id="" class="text-primary font-weight-bold">
                    <?php 
                    echo TEXT_UPLOAD_IMAGES . '&nbsp;&nbsp;
                         <input type="file" name="file[]" multiple>' .
                         TEXT_OVERWRITE_IMAGES . ' 
                         <input type="checkbox" name="overwrite_images" ' . (OVERWRITE_IMAGES ? 'checked=checked' : '') . '>&nbsp;&nbsp;
                         <input type="submit" name="buttoninsert" value="overwrite_images">';
                    ?>
                   </div>
                  </form>
                 </td>
                </tr>
              </table>
             </div>
            </div> 
          </td>

          <td width="25%" valign="top" style="border-style:solid; border-width:thin; border-color:#CCCCCC;background:#F0F0F0;">
          <p style="margin-top:8px;text-align:center;"><a href="EPDocumentation/index.html" target="_blank" style="font-size:16px; text-decoration:underline;">EP Documentation</a></p>

          <?php if (EP_SHOW_EP_SETTINGS == true) { ?>
          <table border="0" cellpadding="0" cellspacing="0"><tr><td class="">
            
             <p style="margin-top:8px;text-align:center;font-weight:bold;">Settings & Info</p>
             <p>EP version: <?php echo EP_CURRENT_VERSION; ?><br />
             <?php        
             if (defined('PROJECT_VERSION')) { echo PROJECT_VERSION . ' ' . $system['oscommerce']['version'] . '<br>'; } ?>
             <?php echo 'OS: ' . $system['system']['os'] . ' ' . isset($system['kernel']) ?? 'unknown' . '<br>'; ?>
             <?php echo 'HTTP: ' . $system['system']['http_server'] . '<br>'; ?>
             <?php echo 'DB: ' . $system['mysql']['version'] . '<br>'; ?>
             <?php echo 'PHP: ' . $system['php']['version'] . ' (Zend: ' . isset($system['zend']) ?? 'unknown' . ')' . '<br>'; ?>
             <br />Temp Directory:<br />
             <?php echo EP_TEMP_DIRECTORY; ?><br />
             <?php if (is_writable(EP_TEMP_DIRECTORY)) { ?><font color="#009900">Temp Dir is Writable</font><?php } else { ?><font color="#FF0000">Temp Dir is NOT Writable</font><?php } ?><br />
             Magic Quotes is: <?php if (ini_get('magic_quotes_runtime') == 1){ echo 'on'; } else { echo 'off'; } ?><br />
             Split files on: <?php echo EP_SPLIT_MAX_RECORDS; ?> records<br />
             Model Number Size: <?php echo $options_array['option_model_size']; ?><br />
             Price with tax: <?php echo (EP_PRICE_WITH_TAX?'true':'false'); ?><br />
             Calc Precision: <?php echo EP_PRECISION; ?><br />
             Replace quotes: <?php echo (EP_REPLACE_QUOTES?'true':'false'); ?><br />
             Field seperator:
             <?php switch ($ep_separator) {
               case "\t";
                 echo 'tab';
                 break;
               case ",";
                 echo 'comma';
                 break;
               case ";";
                 echo 'semi-colon';
                 break;
               case "~";
                 echo 'tilde';
                 break;
               case "-";
                 echo 'dash';
                 break;
               case "*";
                 echo 'splat';
                 break;
             }
             ?><br />
             Excel safe output: <?php echo (EP_EXCEL_SAFE_OUTPUT?'true':'false'); ?><br />
             Preserve tab/cr/lf: <?php echo (EP_PRESERVE_TABS_CR_LF?'true':'false'); ?><br />
             Category depth: <?php echo EP_MAX_CATEGORIES; ?><br />
             Enable attributes: <?php echo (EP_PRODUCTS_WITH_ATTRIBUTES?'true':'false'); ?><br />
             SEF Google Shopping URLS: <?php echo (EP_SEF_URLS ? 'true' : 'false'); ?><br />
             <br />
             <u>Other Support:</u><br />
             <?php echo tep_draw_form('ep_settings', 'easypopulate.php', '', 'post') . tep_hide_session_id() . tep_draw_hidden_field('action', 'settings'); ?>
       
             <div style="white-space:nowrap;"><?php echo DisplayOption("option_xsell"); ?>Cross Sell</div>                        
             <div style="white-space:nowrap;"><?php echo DisplayOption("option_extra_fields"); ?>Extra Fields</div>                        
             <div style="white-space:nowrap;"><?php echo DisplayOption("option_header_tags_seo"); ?>Header Tags SEO </div>                       
             <div style="white-space:nowrap;"><?php echo DisplayOption("option_master_products"); ?>Master Products</div>                        
             <div style="white-space:nowrap;"><?php echo DisplayOption("option_mvs"); ?>MVS Support</div>                         
             <div style="white-space:nowrap;"><?php echo DisplayOption("option_pdf_upload"); ?>PDF Upload</div>                         
             <div style="white-space:nowrap;"><?php echo DisplayOption("option_product_images"); ?>Products Images</div>                         
             <div style="white-space:nowrap;"><?php echo DisplayOption("option_quantity_prices"); ?>Quantity Prices</div>                                     
             <div style="white-space:nowrap;"><?php echo DisplayOption("option_sppc"); ?>SPPC</div>                         
             <br />
             </form>
             <div style="padding: 10px; background-color: #ffffCC">Please see the manual in this contribution's package for help in changing these settings.</div>

          </td></tr></table>
          <?php } ?>

          </td>
        </tr>
      </table>
    </td>
 </tr>
</table>

<?php
//*******************************
//*******************************
// end: MAIN MENU
//*******************************
//*******************************
 

///////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////
// 
// ep_create_filelayout()
// 
///////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////
function ep_create_filelayout($dltype, $attribute_options_array, $languages, $custom_fields){
    global $options_array;

    // depending on the type of the download the user wanted, create a file layout for it.
    $fieldmap = array(); // default to no mapping to change internal field names to external.
 
    // build filters
    $sql_filter = '';
    if (isset($_GET['epcust_category_filter'])) {
        $sub_categories = array();
        $categories_query_addition = 'ptoc.categories_id = ' . (int)$_GET['epcust_category_filter'] . '';
        tep_get_sub_categories($sub_categories, $_GET['epcust_category_filter']);
        foreach ($sub_categories AS $ckey => $category ) {
            $categories_query_addition .= ' or ptoc.categories_id = ' . (int)$category . '';
        }
        $sql_filter .= ' and (' . $categories_query_addition . ')';
    }
    if (isset($_GET['epcust_manufacturer_filter']) && $_GET['epcust_manufacturer_filter'] != '') {
        $sql_filter .= ' and p.manufacturers_id = ' . (int)$_GET['epcust_manufacturer_filter'];
    }
    if (isset($_GET['epcust_status_filter']) && $_GET['epcust_status_filter'] != '') {
        $sql_filter .= ' and p.products_status = ' . (int)$_GET['epcust_status_filter'];
    }

    // building fields
    $ep_products_layout_product = '';
    if ($options_array['option_product_images']) { 
        for ($i = 1; $i <= EP_PRODUCTS_IMAGES_MAX+1; ++$i) {
            $ep_products_layout_product .= '$filelayout[\'v_products_images_image_'.$i.'\'] = $iii++;
                            $filelayout[\'v_products_images_htmlcontent_'.$i.'\'] = $iii++;';
        }
    }
    
    // building fields
    if ($options_array['option_quantity_prices']) { 
        for ($i=1;$i<=EP_QPBP_MAX+1;$i++) {
            $ep_products_layout_product .= '$filelayout[\'v_products_qpbp_price_'.$i.'\'] = $iii++;
                            $filelayout[\'v_products_qpbp_qty_'.$i.'\'] = $iii++;';
        }
    }
    
    // /////////////////////////////////////////////////////////////////////
    //
    // Start: Support for other contributions
    //
    // /////////////////////////////////////////////////////////////////////
    
    $ep_additional_layout_product = '';
    $ep_additional_layout_product_select = '';
    $ep_additional_layout_product_description = '';
    $ep_additional_layout_pricing = '';
    
    if ( $dltype == 'full'){
        foreach ($custom_fields['products'] as $key => $name) { 
            $ep_additional_layout_product .= '$filelayout[\'v_' . $key . '\'] = $iii++;                                            ';
            $ep_additional_layout_product_select .= 'p.' . $key . ' as v_' . $key . ',';
        }
    }
	
    if ($options_array['option_pdf_upload']) { 
        $ep_additional_layout_product .= '$filelayout[\'v_products_pdfupload\'] = $iii++;
        $filelayout[\'v_products_fileupload\'] = $iii++;';
    }
	
    if ($options_array['option_pdf_upload']) {
        $ep_additional_layout_product_select .='p.products_pdfupload as v_products_pdfupload,p.products_fileupload as v_products_fileupload,';
    }
    
    if ($options_array['option_sppc']) { 
        if (isset($_GET['epcust_specials_price'])) { 
            $ep_additional_layout_pricing .= '$filelayout[\'v_customer_price_1\'] = $iii++;
                                              $filelayout[\'v_customer_specials_price_1\'] = $iii++;
                                              $filelayout[\'v_customer_group_id_1\'] = $iii++;
                                              $filelayout[\'v_customer_price_2\'] = $iii++;
                                              $filelayout[\'v_customer_specials_price_2\'] = $iii++;
                                              $filelayout[\'v_customer_group_id_2\'] = $iii++;
                                              $filelayout[\'v_customer_price_3\'] = $iii++;
                                              $filelayout[\'v_customer_specials_price_3\'] = $iii++;
                                              $filelayout[\'v_customer_group_id_3\'] = $iii++;
                                              $filelayout[\'v_customer_price_4\'] = $iii++;
                                              $filelayout[\'v_customer_specials_price_4\'] = $iii++;
                                              $filelayout[\'v_customer_group_id_4\'] = $iii++;
                                              ';
        } else {
             $ep_additional_layout_pricing .= '$filelayout[\'v_customer_price_1\'] = $iii++;
                                              $filelayout[\'v_customer_group_id_1\'] = $iii++;
                                              $filelayout[\'v_customer_price_2\'] = $iii++;
                                              $filelayout[\'v_customer_group_id_2\'] = $iii++;
                                              $filelayout[\'v_customer_price_3\'] = $iii++;
                                              $filelayout[\'v_customer_group_id_3\'] = $iii++;
                                              $filelayout[\'v_customer_price_4\'] = $iii++;
                                              $filelayout[\'v_customer_group_id_4\'] = $iii++;
                                              ';     
        }
    }
    if ($options_array['option_header_tags_seo']) {
        $ep_additional_layout_product_description .= '$filelayout[\'v_products_seo_title_\'.$lang[\'id\']]    = $iii++;
                                                      $filelayout[\'v_products_seo_description_\'.$lang[\'id\']]     = $iii++;
                                                      $filelayout[\'v_products_seo_keywords_\'.$lang[\'id\']] = $iii++;
                                                      ';
    }
    
    if ($options_array['option_mvs']) {
        $ep_additional_layout_product_select .= 'p.vendors_id as v_vendor_id,';
    }

    if ($options_array['option_master_products']) {
        $ep_additional_layout_product_select .= 'p.products_id as v_products_model_id, p.products_master as v_products_master, p.products_master_status as v_products_master_status, ';
    }
    
    // /////////////////////////////////////////////////////////////////////
    // End: Support for other contributions
    // /////////////////////////////////////////////////////////////////////

    switch( $dltype ) {

    case 'full':
        // The file layout is dynamically made depending on the number of languages
        $iii = 0;
        $filelayout = array();

        $filelayout['v_products_model'] = $iii++;

        foreach ($languages as $key => $lang){
            $filelayout['v_products_name_'.$lang['id']]        = $iii++;
            $filelayout['v_products_description_'.$lang['id']] = $iii++;
            $filelayout['v_products_url_'.$lang['id']]         = $iii++;
            foreach ($custom_fields['products_description'] as $key => $name) { 
                $filelayout['v_' . $key . '_'.$lang['id']]         = $iii++;
            }
            if (!empty($ep_additional_layout_product_description)) {
                eval($ep_additional_layout_product_description);
            }
			
        }

         //     $filelayout['v_products_image'] = $iii++;

        //      if (!empty($ep_additional_layout_product)) {
        //        eval($ep_additional_layout_product);
        //      }
        
        $filelayout['v_products_image'] = $iii++;

        if (!empty($ep_products_layout_product)) { // fix for product images
            eval($ep_products_layout_product);
        }

        if (!empty($ep_additional_layout_product)) {
            eval($ep_additional_layout_product);
        }

        $filelayout['v_products_price']    = $iii++;
        $filelayout['v_products_specials_price'] = $iii++;

        if ($options_array['option_mvs']) { 
            $filelayout['v_vendor']    = $iii++;
        }

        if (!empty($ep_additional_layout_pricing)) {
            eval($ep_additional_layout_pricing);
        }

        if ($options_array['option_master_products']) { 
            $filelayout['v_products_master']    = $iii++;
            $filelayout['v_products_master_status']    = $iii++;
        }
        
        $filelayout['v_products_quantity'] = $iii++;
        $filelayout['v_products_weight']   = $iii++;
        $filelayout['v_date_avail']        = $iii++;
        $filelayout['v_date_added']        = $iii++;

        // build the categories name section of the array based on the number of categores the user wants to have
        for($i=1; $i<EP_MAX_CATEGORIES+1; $i++){
            $filelayout['v_categories_image_' . $i] = $iii++;
            foreach ($languages as $key => $lang){
                $filelayout['v_categories_name_' . $i . '_' . $lang['id']] = $iii++;
            }
        }

        $filelayout['v_manufacturers_name'] = $iii++;

        // VJ product attribs begin
        $attribute_options_count = 1;
        foreach ($attribute_options_array as $tkey => $attribute_options_values) {
            $filelayout['v_attribute_options_id_'.$attribute_options_count] = $iii++;
            foreach ($languages as $tkey => $lang ) {
                $filelayout['v_attribute_options_name_'.$attribute_options_count.'_'.$lang['id']] = $iii++;
            }

            $attribute_values_query = "select products_options_values_id  from products_options_values_to_products_options where products_options_id = '" . (int)$attribute_options_values['products_options_id'] . "' order by products_options_values_id";
            $attribute_values_values = tep_db_query($attribute_values_query);

            $attribute_values_count = 1;
            while ($attribute_values = tep_db_fetch_array($attribute_values_values)) {
                $filelayout['v_attribute_values_id_'.$attribute_options_count.'_'.$attribute_values_count] = $iii++;
                foreach ($languages as $tkey => $lang ) {
                    $filelayout['v_attribute_values_name_'.$attribute_options_count.'_'.$attribute_values_count.'_'.$lang['id']] = $iii++;
                }
                $filelayout['v_attribute_values_price_'.$attribute_options_count.'_'.$attribute_values_count] = $iii++;
                //// attributes stock add start        
                if ( EP_PRODUCTS_ATTRIBUTES_STOCK == true ) { 
                    $filelayout['v_attribute_values_stock_'.$attribute_options_count.'_'.$attribute_values_count] = $iii++;
                }                
                //// attributes stock add end         
                $attribute_values_count++;
             }
            $attribute_options_count++;
        }
        // VJ product attribs end

        $filelayout['v_tax_class_title']  = $iii++;
        $filelayout['v_status']           = $iii++;

        $filelayout_sql = "SELECT
            p.products_id as v_products_id,
            p.products_model as v_products_model,
            p.products_image as v_products_image,
            $ep_additional_layout_product_select
            p.products_price as v_products_price,
            p.products_weight as v_products_weight,
            p.products_date_available as v_date_avail,
            p.products_date_added as v_date_added,
            p.products_tax_class_id as v_tax_class_id,
            p.products_quantity as v_products_quantity,
            p.manufacturers_id as v_manufacturers_id,
            subc.categories_id as v_categories_id,
            p.products_status as v_status
            FROM
            products as p,
            categories as subc,
            products_to_categories as ptoc
            WHERE
            p.products_id = ptoc.products_id AND
            ptoc.categories_id = subc.categories_id
            " . $sql_filter;

        break;

    case 'priceqty':
        $iii = 0;
        $filelayout = array();

        $filelayout['v_products_model']    = $iii++;
        $filelayout['v_products_price']    = $iii++;
        $filelayout['v_products_quantity'] = $iii++;
        
        if (!empty($ep_additional_layout_pricing)) {
            eval($ep_additional_layout_pricing);
        }

        $filelayout_sql = "SELECT
            p.products_id as v_products_id,
            p.products_model as v_products_model,
            p.products_price as v_products_price,
            p.products_tax_class_id as v_tax_class_id,
            p.products_quantity as v_products_quantity
            FROM
            products as p
            ";
        break;

    case 'masterstatus':
        $iii = 0;
        $filelayout = array();

        $filelayout['v_products_model_id']      = $iii++;
        $filelayout['v_products_model']         = $iii++;
        $filelayout['v_products_master']        = $iii++;
        $filelayout['v_products_master_status'] = $iii++;
        
        if (!empty($ep_additional_layout_pricing)) {
          eval($ep_additional_layout_pricing);
        }

        $filelayout_sql = "SELECT
            p.products_id as v_products_id,
            p.products_id as v_products_model_id,
            p.products_model as v_products_model,
            p.products_master as v_products_master,
            p.products_master_status as v_products_master_status
            FROM
            products as p
            ";
        break;

        case 'prodimage':
        $iii = 0;
        $filelayout = array();

        $filelayout['v_products_model'] = $iii++;

        foreach ($languages as $key => $lang){
            $filelayout['v_products_name_'.$lang['id']] = $iii++;
            //$filelayout['v_products_description_'.$lang['id']] = $iii++;
            //$filelayout['v_products_url_'.$lang['id']]            = $iii++;
            foreach ($custom_fields['products_description'] as $key => $name) { 
                $filelayout['v_' . $key . '_'.$lang['id']]              = $iii++;
            }
            if (!empty($ep_additional_layout_product_description)) {
                eval($ep_additional_layout_product_description);
            }                        
        }

        $filelayout['v_products_image'] = $iii++;

        if (!empty($ep_products_layout_product)) { // fix for product images
            eval($ep_products_layout_product);
        }

        if (!empty($ep_additional_layout_product)) {
            eval($ep_additional_layout_product);
        }
        
        $filelayout_sql = "SELECT
                p.products_id as v_products_id,
                p.products_model as v_products_model,
                p.products_image as v_products_image,
                $ep_additional_layout_product_select
                p.products_status as v_status
                FROM
                products as p
                " . $sql_filter;
        break;

    case 'custom':
        $iii = 0;
        $filelayout = array();
        $filelayout['v_products_model'] = $iii++;

        if (isset($_GET['epcust_status'])) { 
            $filelayout['v_status'] = $iii++; 
        }
        
        foreach ($languages as $key => $lang) {
            if (isset($_GET['epcust_name'])) { $filelayout['v_products_name_'.$lang['id']] = $iii++; }
            if (isset($_GET['epcust_description'])) { $filelayout['v_products_description_'.$lang['id']] = $iii++; }
            if (isset($_GET['epcust_url'])) { $filelayout['v_products_url_'.$lang['id']] = $iii++; }
            foreach ($custom_fields['products_description'] as $key => $name) { 
                if (isset($_GET['epcust_' . $key])) { 
                    $filelayout['v_' . $key . '_'.$lang['id']] = $iii++; 
                }
            }
        }

        if (isset($_GET['epcust_image']) || isset($_GET['epcust_prod_images'])) {
            $filelayout['v_products_image'] = $iii++;

            if (!empty($ep_products_layout_product)) { // fix for product images
                eval($ep_products_layout_product);
            }

            if (!empty($ep_additional_layout_product)) {
                eval($ep_additional_layout_product);
            }
        }

        foreach ($custom_fields['products'] as $key => $name) { 
            if (isset($_GET['epcust_' . $key])) {
                $filelayout['v_' . $key] = $iii++;
                $ep_additional_layout_product_select .= 'p.' . $key . ' as v_' . $key . ',';
            }
        }

        if (isset($_GET['epcust_price'])) { $filelayout['v_products_price'] = $iii++; }
        if (isset($_GET['epcust_specials_price'])) { $filelayout['v_products_specials_price'] = $iii++; }
        if (isset($_GET['epcust_quantity'])) { $filelayout['v_products_quantity'] = $iii++; }
        if (isset($_GET['epcust_weight'])) { $filelayout['v_products_weight'] = $iii++; }
        if (isset($_GET['epcust_date_avail'])) { $filelayout['v_date_avail'] = $iii++; }
        if (isset($_GET['epcust_date_added'])) { $filelayout['v_date_added'] = $iii++; }
		
        if (isset($_GET['epcust_category'])) {
            // build the categories name section of the array based on the number 
            // of categores the user wants to have
            for($i=1; $i<=EP_MAX_CATEGORIES; $i++) {
                $filelayout['v_categories_image_'.$i] = $iii++;
                foreach ($languages as $key => $lang){
                    $filelayout['v_categories_name_'.$i.'_'.$lang['id']] = $iii++;
                }
            }
        }

        if (isset($_GET['epcust_manufacturer'])) { $filelayout['v_manufacturers_name'] = $iii++; }

        if (isset($_GET['epcust_attributes'])) {
          // VJ product attribs begin
          $attribute_options_count = 1;
          foreach ($attribute_options_array as $tkey => $attribute_options_values) {
            $filelayout['v_attribute_options_id_'.$attribute_options_count] = $iii++;
            foreach ($languages as $tkey => $lang ) {
                $filelayout['v_attribute_options_name_'.$attribute_options_count.'_'.$lang['id']] = $iii++;
            }

            $attribute_values_query = "select products_options_values_id  from products_options_values_to_products_options where products_options_id = '" . (int)$attribute_options_values['products_options_id'] . "' order by products_options_values_id";
            $attribute_values_values = tep_db_query($attribute_values_query);

            $attribute_values_count = 1;
            while ($attribute_values = tep_db_fetch_array($attribute_values_values)) {
                $filelayout['v_attribute_values_id_'.$attribute_options_count.'_'.$attribute_values_count] = $iii++;
                foreach ($languages as $tkey => $lang ) {
                    $filelayout['v_attribute_values_name_'.$attribute_options_count.'_'.$attribute_values_count.'_'.$lang['id']] = $iii++;
                }
                $filelayout['v_attribute_values_price_'.$attribute_options_count.'_'.$attribute_values_count] = $iii++;
                //// attributes stock add start        
                if ( EP_PRODUCTS_ATTRIBUTES_STOCK == true ) { 
                    $filelayout['v_attribute_values_stock_'.$attribute_options_count.'_'.$attribute_values_count] = $iii++;
                }                
                //// attributes stock add end         
                $attribute_values_count++;
             }
            $attribute_options_count++;
          }
          // VJ product attribs end
        }
        if ($options_array['option_mvs']) {
            if (isset($_GET['epcust_vendor'])) { $filelayout['v_vendor'] = $iii++; }
        }

        if ($options_array['option_master_products']) {
            if (isset($_GET['epcust_products_master'])) { $filelayout['v_products_master'] = $iii++; }
            if (isset($_GET['epcust_products_master_status'])) { $filelayout['v_products_master_status'] = $iii++; }
            if (isset($_GET['epcust_products_model_id'])) { $filelayout['v_products_model_id'] = $iii++; }
        }
        
        if (isset($_GET['epcust_sppc'])) {
            if (!empty($ep_additional_layout_pricing)) {
                eval($ep_additional_layout_pricing);
            }
        }

        if (isset($_GET['epcust_tax_class'])) { $filelayout['v_tax_class_title'] = $iii++; }
        if (isset($_GET['epcust_comment'])) { $filelayout['v_products_comment'] = $iii++; }
        if (isset($_GET['epcust_cross_sell'])) { $filelayout['v_cross_sell'] = $iii++; }

        $filelayout_sql = "SELECT
            p.products_id as v_products_id,
            p.products_model as v_products_model,
            p.products_status as v_status,
            p.products_price as v_products_price,
            p.products_quantity as v_products_quantity,
            p.products_weight as v_products_weight,
            p.products_image as v_products_image,
            $ep_additional_layout_product_select
            p.manufacturers_id as v_manufacturers_id,
            p.products_date_available as v_date_avail,
            p.products_date_added as v_date_added,
            p.products_tax_class_id as v_tax_class_id,
            subc.categories_id as v_categories_id
            FROM
            products as p,
            categories as subc,
            products_to_categories as ptoc
            WHERE
            p.products_id = ptoc.products_id AND
            ptoc.categories_id = subc.categories_id
            " . $sql_filter;
        break;

    case 'category':
        $iii = 0;
        $filelayout = array();
        
        $filelayout['v_products_model'] = $iii++;

        for($i=1; $i<EP_MAX_CATEGORIES+1; $i++){
            $filelayout['v_categories_image_'.$i] = $iii++;
            foreach ($languages as $key => $lang){
                $filelayout['v_categories_name_'.$i.'_'.$lang['id']] = $iii++;
            }
        }

        $filelayout_sql = "SELECT
            p.products_id as v_products_id,
            p.products_model as v_products_model,
            subc.categories_id as v_categories_id
            FROM
            products as p,
            categories as subc,
            products_to_categories as ptoc            
            WHERE
            p.products_id = ptoc.products_id AND
            ptoc.categories_id = subc.categories_id
            ";
        break;

    case 'extra_fields':
    // start EP for product extra field ============================= DEVSOFTVN - 10/20/2005     
        $iii = 0;
        $filelayout = array(
            'v_products_model' => $iii++,
            'v_products_extra_fields_name' => $iii++, 
            'v_products_extra_fields_id' => $iii++,
//            'v_products_id'        => $iii++,
            'v_products_extra_fields_value' => $iii++,
                        );
    
        $filelayout_sql = "SELECT
                        p.products_id as v_products_id,
                        p.products_model as v_products_model,
                        subc.products_extra_fields_id as v_products_extra_fields_id,
                        subc.products_extra_fields_value as v_products_extra_fields_value,
                        ptoc.products_extra_fields_name as v_products_extra_fields_name
                        FROM
                        products as p,
                        products_to_products_extra_fields as subc,
                        products_extra_fields as ptoc
                        WHERE
                        p.products_id = subc.products_id AND
                        ptoc.products_extra_fields_id = subc.products_extra_fields_id
                        ";    
    // end of EP for extra field code ======= DEVSOFTVN================       
        break;


    case 'google_shopping':
        // this is going to be a little interesting because we need
        // a way to map from internal names to external names
        //
        // Before it didn't matter, but with google_shopping needing particular headers,
        // The file layout is dynamically made depending on the number of languages
        $iii = 0;
        $filelayout = array();

        $filelayout['v_google_shopping_products_url_1'] = $iii++;
        $filelayout['v_google_shopping_products_name_'.EP_DEFAULT_LANGUAGE_ID] = $iii++;
        $filelayout['v_google_shopping_products_description_'.EP_DEFAULT_LANGUAGE_ID] = $iii++;
        $filelayout['v_products_price'] = $iii++;
        $filelayout['v_products_fullpath_image'] = $iii++;
        $filelayout['v_google_shopping_product_id'] = $iii++;
        $filelayout['v_google_shopping_quantitylevel'] = $iii++;
        $filelayout['v_category_fullpath'] = $iii++;
        $filelayout['v_google_shopping_exp_date'] = $iii++;
        $filelayout['v_google_shopping_currency'] = $iii++;

        $iii=0;
        $fileheaders = array();

        // EP Support mapping new names to the export headers.
        // use the $fileheaders[''] vars to do that.
        $fileheaders['link'] = $iii++;
        $fileheaders['title'] = $iii++;
        $fileheaders['description'] = $iii++;
        $fileheaders['price'] = $iii++;
        $fileheaders['image_link'] = $iii++;
        $fileheaders['id'] = $iii++;
        $fileheaders['quantity'] = $iii++;
        $fileheaders['product_type'] = $iii++;
        $fileheaders['expiration_date'] = $iii++;
        $fileheaders['currency'] = $iii++;

        $filelayout_sql = "SELECT
            p.products_id as v_products_id,
            p.products_model as v_products_model,
            p.products_image as v_products_image,
            p.products_price as v_products_price,
            p.products_weight as v_products_weight,
            p.products_date_added as v_date_added,
            p.products_date_available as v_date_avail,
            p.products_tax_class_id as v_tax_class_id,
            p.products_quantity as v_products_quantity,
            p.manufacturers_id as v_manufacturers_id,
            subc.categories_id as v_categories_id
            FROM
            products as p,
            categories as subc,
            products_to_categories as ptoc
            WHERE
            p.products_id = ptoc.products_id AND
            ptoc.categories_id = subc.categories_id
            " . $sql_filter;
        break;

    // VJ product attributes begin
    case 'attrib':
        $iii = 0;
        $filelayout = array();

        $filelayout['v_products_model'] = $iii++;

        $attribute_options_count = 1;
        foreach ($attribute_options_array as $tkey1 => $attribute_options_values) {
            $filelayout['v_attribute_options_id_'.$attribute_options_count] = $iii++;
            foreach ($languages as $tkey => $lang ) {
                $filelayout['v_attribute_options_name_'.$attribute_options_count.'_'.$lang['id']] = $iii++;
            }

            $attribute_values_query = "select products_options_values_id  from products_options_values_to_products_options where products_options_id = '" . (int)$attribute_options_values['products_options_id'] . "' order by products_options_values_id";
            $attribute_values_values = tep_db_query($attribute_values_query);

            $attribute_values_count = 1;
            while ($attribute_values = tep_db_fetch_array($attribute_values_values)) {
                $filelayout['v_attribute_values_id_'.$attribute_options_count.'_'.$attribute_values_count] = $iii++;
                foreach ($languages as $tkey2 => $lang ) {
                    $filelayout['v_attribute_values_name_'.$attribute_options_count.'_'.$attribute_values_count.'_'.$lang['id']] = $iii++;
                }
                $filelayout['v_attribute_values_price_'.$attribute_options_count.'_'.$attribute_values_count] = $iii++;
                //// attributes stock add start        
                if ( EP_PRODUCTS_ATTRIBUTES_STOCK    == true ) { 
                    $header_array['v_attribute_values_stock_'.$attribute_options_count.'_'.$attribute_values_count] = $iii++;
                }                
                //// attributes stock add end         
                $attribute_values_count++;
            }
            $attribute_options_count++;
        }

        $filelayout_sql = "SELECT
                            p.products_id as v_products_id,
                            p.products_model as v_products_model
                            FROM
                            products as p
                            ";

        break;
        // VJ product attributes end
    }

    $filelayout_count = count($filelayout);
   
    if (! isset($fileheaders)) $fileheaders = [];
 
    return array($filelayout, $filelayout_count, $filelayout_sql, $fileheaders);
}



///////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////
// 
// process_row()
//
//   Processes one row of the import file
// 
///////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////
function process_row( $item1, $filelayout, $filelayout_count, $default_these, $ep_separator, $languages, $custom_fields ) {
    global $options_array;
    
    // first we clean up the row of data
    if (EP_EXCEL_SAFE_OUTPUT == true) {
        $items = $item1;
    } else {
        // chop blanks from each end
        $item1 = ltrim(rtrim($item1));
      
        // blow it into an array, splitting on the tabs
        $items = explode($ep_separator, $item1);
    }

    // make sure all non-set things are set to '';
    // and strip the quotes from the start and end of the stings.
    // escape any special chars for the database.
    foreach( $filelayout as $key => $value) {
        $i = $filelayout[$key];
        if (isset($items[$i]) == false) {
            $items[$i] = '';
        } else {
            // check if the last character is a quote;
            // if it is, chop off the 1st and last character of the string.
            if (substr($items[$i],-1) == '"' && substr($items[$i],0,1) == '"'){
                //$items[$i] = substr($items[$i],1,strlen($items[$i])-2);
                $items[$i] = trim('"', $items[$i]);
            }
            
            // now any remaining doubled double quotes should be converted to one doublequote
            if (EP_REPLACE_QUOTES == true){
                if (EP_EXCEL_SAFE_OUTPUT == true) {
                  $items[$i] = str_replace('""',"&#34;",$items[$i]);
                }
                $items[$i] = str_replace('"',"&#34;",$items[$i]);
                $items[$i] = str_replace("'","&#39;",$items[$i]);
            }
        }
    }

    // /////////////////////////////////////////////////////////////
    // Do specific functions without processing entire range of vars
    // /////////////////////////////
    // first do product extra fields
    if (isset($filelayout['v_products_extra_fields_id']) ) {    
    
        $v_products_model = $items[$filelayout['v_products_model']];
        // EP for product extra fields Contrib by minhmaster DEVSOFTVN ==========
        $v_products_extra_fields_id = $items[$filelayout['v_products_extra_fields_id']];
        // $v_products_id    =    $items[$filelayout['v_products_id']];
        $v_products_extra_fields_value    =    $items[$filelayout['v_products_extra_fields_value']];
        
        $sql = "SELECT p.products_id as v_products_id FROM products as p WHERE p.products_model = '" . tep_db_input($v_products_model) . "'";
        $result = tep_db_query($sql);
        $row =  tep_db_fetch_array($result);

        $sql_exist	=	"SELECT products_extra_fields_value FROM products_to_products_extra_fields WHERE (products_id ='". (int)$row['v_products_id']. "') AND (products_extra_fields_id ='". tep_db_input($v_products_extra_fields_id) ."')";

        if (tep_db_num_rows(tep_db_query($sql_exist)) > 0) {
            $sql_extra_field	=	"UPDATE products_to_products_extra_fields SET products_extra_fields_value='". tep_db_input($v_products_extra_fields_value)."' WHERE (products_id ='". (int)$row['v_products_id'] . "') AND (products_extra_fields_id ='".$v_products_extra_fields_id ."')";
            $str_err_report= " $v_products_extra_fields_id | $v_products_id  | $v_products_model | $v_products_extra_fields_value | <b><font color=black>Product Extra Fields Updated</font></b><br />";
        } else {
            $sql_extra_field	=	"INSERT INTO products_to_products_extra_fields(products_id,products_extra_fields_id,products_extra_fields_value) VALUES ('". $row['v_products_id'] ."','". (int)$v_products_extra_fields_id."','".$v_products_extra_fields_value."')";
            $str_err_report= " $v_products_extra_fields_id | $v_products_id | $v_products_model | $v_products_extra_fields_value | <b><font color=green>Product Extra Fields Inserted</font></b><br />";
        }

        $result = tep_db_query($sql_extra_field);
        
        echo $str_err_report;
        // end (EP for product extra fields Contrib by minhmt DEVSOFTVN) ============
        
    // /////////////////////
    // or do product deletes
    } elseif ( $items[$filelayout['v_status']] == EP_DELETE_IT ) {
        // Get the ID
        $sql = "SELECT p.products_id as v_products_id FROM products as p WHERE p.products_model = '" . $items[$filelayout['v_products_model']] . "'";
        $result = tep_db_query($sql);
        $row =  tep_db_fetch_array($result);
         
        if (tep_db_num_rows($result)) {
            tep_remove_product($row['v_products_id']);        

            if (function_exists('tep_reset_cache_block')) {  //not used by Phoenix but may have been added by an addon
                tep_reset_cache_block('categories');
                tep_reset_cache_block('also_purchased');
            }
            
            echo "Deleted product " . $items[$filelayout['v_products_model']] . " from the database<br />";
           
        } else {
            echo "Did not delete " . $items['v_products_model'] . " since it is not unique<br> ";
        }
     
    // //////////////////////////////////
    // or do regular product processing
    // //////////////////////////////////
    } else {

        // /////////////////////////////////////////////////////////////////////
        //
        // Start: Support for other contributions in products table
        //
        // /////////////////////////////////////////////////////////////////////
        $ep_additional_select = '';
	
        if ($options_array['option_pdf_upload']) { 
            $ep_additional_select .='p.products_pdfupload as v_products_pdfupload, p.products_fileupload as v_products_fileupload,';
        }

        if ($options_array['option_mvs']) {
            $ep_additional_select .= 'vendors_id as v_vendor_id,';
        }

        if ($options_array['option_master_products']) {
            $ep_additional_select .='p.products_master as v_products_master, p.products_master_status as v_products_master_status,';
        }

        foreach ($custom_fields['products'] as $key => $name) { 
            $ep_additional_select .= 'p.' . $key . ' as v_' . $key . ',';
        }

        // /////////////////////////////////////////////////////////////////////
        // End: Support for other contributions in products table
        // /////////////////////////////////////////////////////////////////////    
    
        // now do a query to get the record's current contents
        $sql = "SELECT
                    p.products_id as v_products_id,
                    p.products_model as v_products_model,
                    p.products_image as v_products_image,
                    $ep_additional_select
                    p.products_price as v_products_price,
                    p.products_weight as v_products_weight,
                    p.products_date_available as v_date_avail,
                    p.products_date_added as v_date_added,
                    p.products_tax_class_id as v_tax_class_id,
                    p.products_quantity as v_products_quantity,
                    p.manufacturers_id as v_manufacturers_id,
                    subc.categories_id as v_categories_id,
                    p.products_status as v_status_current
                FROM
                    products as p,
                    categories as subc,
                    products_to_categories as ptoc
                WHERE
                    p.products_model = '" . $items[$filelayout['v_products_model']] . "' AND
                    p.products_id = ptoc.products_id AND
                    ptoc.categories_id = subc.categories_id
                LIMIT 1
            ";

        $result = tep_db_query($sql);
        $row =  tep_db_fetch_array($result);

        // determine processing status based on dropdown choice on EP menu
        if (tep_db_num_rows($result) > 0 && ($_POST['imput_mode'] == "normal" || $_POST['imput_mode'] == "update")) {
            $process_product = true;
        } elseif ((is_null($row) || sizeof($row) == 1) && ($_POST['imput_mode'] == "normal" || $_POST['imput_mode'] == "addnew")) {
                $process_product = true;
        } else {
                $process_product = false;
        }

        if ($process_product == true) {
            while ($row) {
                // OK, since we got a row, the item already exists.
                // Let's get all the data we need and fill in all the fields that need to be defaulted 
                // to the current values for each language, get the description and set the vals
                foreach ($languages as $key => $lang){
                    // products_name, products_description, products_url
                    $sql2 = "SELECT * 
                            FROM products_description
                            WHERE
                                products_id = " . $row['v_products_id'] . " AND
                                language_id = '" . $lang['id'] . "'
                            LIMIT 1
                            ";
                    $result2 = tep_db_query($sql2);
                    $row2 =  tep_db_fetch_array($result2);
                    // Need to report from ......_name_1 not ..._name_0
                    
                    $row['v_products_name_' . $lang['id']]        = $row2['products_name']; 
                    $row['v_products_description_' . $lang['id']] = $row2['products_description'];
                    $row['v_products_url_' . $lang['id']]         = $row2['products_url'];
                    foreach ($custom_fields['products_description'] as $key => $name) { 
                        $row['v_' . $key . '_' . $lang['id']]         = $row2[$key];
                    }
                    // header tags controller support
                    if(isset($filelayout['v_products_seo_title_' . $lang['id'] ])){
                        $row['v_products_seo_title_' . $lang['id']]    = $row2['products_seo_title'];
                        $row['v_products_seo_description_' . $lang['id']]     = $row2['products_seo_description'];
                        $row['v_products_seo_keywords_' . $lang['id']] = $row2['products_seo_keywords'];
                    }
                    // end: header tags controller support
                }
        
                // start with v_categories_id
                // Get the category description
                // set the appropriate variable name
                // if parent_id is not null, then follow it up.
                $thecategory_id = $row['v_categories_id'];
                for( $categorylevel=1; $categorylevel<=(EP_MAX_CATEGORIES+1); $categorylevel++) {
                    if ($thecategory_id) {
                 
                        $sql3 = "SELECT parent_id, categories_image FROM categories WHERE categories_id = " . (int)$thecategory_id . '';
                        $result3 = tep_db_query($sql3);
                        if ($row3 = tep_db_fetch_array($result3)) {
                            $temprow['v_categories_image_' . $categorylevel] = $row3['categories_image'];
                        }
                    
                        foreach ($languages as $key => $lang){
                            $sql2 = "SELECT categories_name FROM categories_description
                                  WHERE    
                                      categories_id = " . (int)$thecategory_id . " AND
                                      language_id = " . (int)$lang['id'];
                            $result2 = tep_db_query($sql2);
                            if ($row2 =  tep_db_fetch_array($result2)) {
                                $temprow['v_categories_name_' . $categorylevel . '_' . $lang['id']] = $row2['categories_name'];
                            }
                        }
                    
                        // now get the parent ID if there was one
                        $theparent_id = $row3['parent_id'];
                        if ($theparent_id != ''){
                            // there was a parent ID, lets set thecategoryid to get the next level
                            $thecategory_id = $theparent_id;
                        } else {
                            // we have found the top level category for this item,
                            $thecategory_id = false;
                        }
                  
                    } else {
                        $temprow['v_categories_image_' . $categorylevel] = '';
                        foreach ($languages as $key => $lang){
                            $temprow['v_categories_name_' . $categorylevel . '_' . $lang['id']] = '';
                        }
                    }
                }
                            // temprow has the old style low to high level categories.
                $newlevel = 1;
                // let's turn them into high to low level categories
                for( $categorylevel=EP_MAX_CATEGORIES+1; $categorylevel>0; $categorylevel--){
                    $found = false;
                    if ($temprow['v_categories_image_' . $categorylevel] != ''){
                        $row['v_categories_image_' . $newlevel] = $temprow['v_categories_image_' . $categorylevel];
                        $found = true;
                    }
                    foreach ($languages as $key => $lang){
                        if ($temprow['v_categories_name_' . $categorylevel . '_' . $lang['id']] != ''){
                            $row['v_categories_name_' . $newlevel . '_' . $lang['id']] = $temprow['v_categories_name_' . $categorylevel . '_' . $lang['id']];
                            $found = true;
                        }
                    }
                    if ($found == true) {
                        $newlevel++;
                    }
                }

			            	// default the manufacturer        
                if ($row['v_manufacturers_id'] != ''){
                    $sql2 = "SELECT manufacturers_name
                        FROM manufacturers
                        WHERE
                        manufacturers_id = " . (int)$row['v_manufacturers_id'];
                    $result2 = tep_db_query($sql2);
                    $row2 =  tep_db_fetch_array($result2);
                    $row['v_manufacturers_name'] = $row2['manufacturers_name'];
                }

                if ($options_array['option_mvs']) {
                    $result2 = tep_db_query("select vendors_name from vendors WHERE vendors_id = " . $row['v_vendor_id']);
                    $row2 =  tep_db_fetch_array($result2);		
                    $row['v_vendor'] = $row2['vendors_name'];
                }

/*                if ($options_array['option_master_products']) {
                  $result2 = tep_db_query("select products_master from products WHERE products_id = " . $row['v_products_id']);
                  $row2 =  tep_db_fetch_array($result2);
                  $row['v_products_master'] = $row2['vendors_name'];
                }
*/                
                //elari -
                //We check the value of tax class and title instead of the id
                //Then we add the tax to price if EP_PRICE_WITH_TAX is set to true
                $row_tax_multiplier = tep_get_tax_class_rate($row['v_tax_class_id']);
                $row['v_tax_class_title'] = tep_get_tax_class_title($row['v_tax_class_id']);
                if (EP_PRICE_WITH_TAX == true){
                    $row['v_products_price'] = $row['v_products_price'] + round(($row['v_products_price'] * $row_tax_multiplier / 100), EP_PRECISION);
                }
                // now create the internal variables that will be used
                // the $$thisvar is on purpose: it creates a variable named what ever was in $thisvar and sets the value
                foreach ($default_these as $tkey => $thisvar){
                    $$thisvar = $row[$thisvar];
                }
        
                $row =  tep_db_fetch_array($result);
            }
        
            // this is an important loop.  What it does is go thru all the fields in the incoming 
            // file and set the internal vars. Internal vars not set here are either set in the 
            // loop above for existing records, or not set at all (null values) the array values 
            // are handled separatly, although they will set variables in this loop, we won't use them.
            foreach( $filelayout as $key => $value ){
                if (!($key == 'v_date_added' && empty($items[ $value ]))) {
                     $$key = $items[ $value ];
                }
            }
        
            //elari... we get the tax_clas_id from the tax_title
            //on screen will still be displayed the tax_class_title instead of the id....
            if ( isset($v_tax_class_title) ){
                $v_tax_class_id = tep_get_tax_title_class_id($v_tax_class_title);
            }
            //we check the tax rate of this tax_class_id
            $row_tax_multiplier = tep_get_tax_class_rate($v_tax_class_id);
        
            //And we recalculate price without the included tax...
            //Since it seems display is made before, the displayed price will still include tax
            //This is same problem for the tax_clas_id that display tax_class_title
            if (EP_PRICE_WITH_TAX == true){
                $v_products_price = round( $v_products_price / (1 + ($row_tax_multiplier * .01)), EP_PRECISION);
            }
        
            // if they give us one category, they give us all categories. convert data structure to a multi-dim array
            unset ($v_categories_name); // default to not set.
            unset ($v_categories_image); // default to not set.
            foreach ($languages as $key => $lang) {
                $baselang_id = $lang['id'];
                break;
            }
            if ( isset( $filelayout['v_categories_name_1_' . $baselang_id] ) ) {
                $v_categories_name = array();
                $v_categories_image = array();
                $newlevel = 1;
                
                for( $categorylevel=EP_MAX_CATEGORIES; $categorylevel>0; $categorylevel--) {
                    $found = false;
                    if ($items[$filelayout['v_categories_image_' . $categorylevel]] != '') {
                        $v_categories_image[$newlevel] = $items[$filelayout['v_categories_image_' . $categorylevel]];
                        $found = true;
                    }
                    foreach ($languages as $key => $lang) {
                        if ( $items[$filelayout['v_categories_name_' . $categorylevel . '_' . $lang['id']]] != ''){
                            $v_categories_name[$newlevel][$lang['id']] = $items[$filelayout['v_categories_name_' . $categorylevel . '_' . $lang['id']]];
                            $found = true;
                        }
                    }
                    if ($found == true) {
                        $newlevel++;
                    }
                }
                
                while( $newlevel < EP_MAX_CATEGORIES+1){
                    $v_categories_image[$newlevel] = ''; // default the remaining items to nothing
                    foreach ($languages as $key => $lang){
                        $v_categories_name[$newlevel][$lang['id']] = ''; // default the remaining items to nothing
                    }
                    $newlevel++;
                }
            }
        
            if (trim($v_products_quantity) == '') {
                $v_products_quantity = 1;
            }
        
            $v_date_avail = (empty($v_date_avail) ? 'NULL' : "'" . date("Y-m-d H:i:s",strtotime($v_date_avail)) . "'");
            $v_date_added = (empty($v_date_added) ? "'" . date("Y-m-d H:i:s") . "'" : "'" . date("Y-m-d H:i:s",strtotime($v_date_added)) . "'");
            $v_db_status =  (isset($v_status_current) ? strval($v_status_current) : '1'); // default to active
            
            if (trim($v_status) == EP_TEXT_INACTIVE){
                // they told us to deactivate this item
                $v_db_status = '0';
            } elseif (trim($v_status) == EP_TEXT_ACTIVE) {
                $v_db_status = '1';
            }    
        
            if (EP_INACTIVATE_ZERO_QUANTITIES == true && $v_products_quantity == 0) {
                // if they said that zero qty products should be deactivated, let's deactivate if the qty is zero
                $v_db_status = '0';
            }
        
            if (! isset($v_manufacturer_id)){
                $v_manufacturer_id = "NULL";
            }
        
            if (trim($v_products_image)==''){
                $v_products_image = EP_DEFAULT_IMAGE_PRODUCT;
            }

            if (isset($v_products_model) && strlen($v_products_model) > $options_array['option_model_size'] ) {
                echo "<font color='red'>" . strlen($v_products_model) . $v_products_model . "... ERROR! - Too many characters in the model number.<br />
                    12 is the maximum on a standard OSC install.<br />
                    Your maximum product_model length is set to ".$options_array['option_model_size'].".<br />
                    You can either shorten your model numbers or increase the size of the<br />
                    \"products_model\" field of the \"products\" table in the database.</font>";
                die();
            }
        
        
            // OK, we need to convert the manufacturer's name into id's for the database
            if ( isset($v_manufacturers_name) && $v_manufacturers_name != '' ){
                $sql = "SELECT man.manufacturers_id
                    FROM manufacturers as man
                    WHERE
                        man.manufacturers_name = '" . tep_db_input($v_manufacturers_name) . "'";
                $result = tep_db_query($sql);
                $row =  tep_db_fetch_array($result);
                if ( $row != '' ){
                    foreach( $row as $item ){
                        $v_manufacturer_id = $item;
                    }
                } else {
                    // to add, we need to put stuff in categories and categories_description
                    $sql = "SELECT MAX( manufacturers_id) max FROM manufacturers";
                    $result = tep_db_query($sql);
                    $row =  tep_db_fetch_array($result);
                    $max_mfg_id = $row['max']+1;
                    // default the id if there are no manufacturers yet
                    if (!is_numeric($max_mfg_id) ){
                        $max_mfg_id=1;
                    }
        
                    $sql = "INSERT INTO manufacturers(
                        manufacturers_id,
                        manufacturers_name,
                        manufacturers_image,
                        date_added,
                        last_modified
                        ) VALUES (
                        $max_mfg_id,
                        '".tep_db_input($v_manufacturers_name)."',
                        '".EP_DEFAULT_IMAGE_MANUFACTURER."',
                        '".date("Y-m-d H:i:s")."',
                        '".date("Y-m-d H:i:s")."'
                        )";
                    $result = tep_db_query($sql);
                    $v_manufacturer_id = $max_mfg_id;
        
                    $sql = "INSERT INTO manufacturers_info (
                        manufacturers_id,
                        manufacturers_url,
                        languages_id
                        ) VALUES (
                        $max_mfg_id,
                        '',
                        '".EP_DEFAULT_LANGUAGE_ID."'
                        )";
                    $result = tep_db_query($sql);
                }
            }
            
            // if the categories names are set then try to update them
            foreach ($languages as $key => $lang){
                $baselang_id = $lang['id'];
                break;
            }
            if ( isset( $filelayout['v_categories_name_1_' . $baselang_id] ) ){
                // start from the highest possible category and work our way down from the parent
                $v_categories_id = 0;
                $theparent_id = 0;
                for ( $categorylevel = EP_MAX_CATEGORIES; $categorylevel > 0; --$categorylevel ) {
				            //foreach ($languages as $key => $lang){
                    $thiscategoryname = $v_categories_name[$categorylevel][$baselang_id];
                    if ( $thiscategoryname != ''){
                        // we found a category name in this field, look for database entry
                        $sql = "SELECT cat.categories_id
                            FROM categories as cat, 
                                 categories_description as des
                            WHERE
                                cat.categories_id = des.categories_id AND
                                des.language_id = " . $baselang_id . " AND
                                cat.parent_id = " . $theparent_id . " AND
                                des.categories_name like '" . tep_db_input($thiscategoryname) . "'";
                        $result = tep_db_query($sql);
                        $row =  tep_db_fetch_array($result);

                        if ( $row != '' ){
                            // we have an existing category, update image and date
						                     	foreach( $row as $item ){
                                $thiscategoryid = $item;
                            }
                            
                            $cat_image = '';
                            if (!empty($v_categories_image[$categorylevel])) {
                                $cat_image = "categories_image='".tep_db_input($v_categories_image[$categorylevel])."', ";
                            } elseif (isset($filelayout['v_categories_image_' . $categorylevel])) {
                                $cat_image = "categories_image='', ";
                            }        
                            
                            $query = "UPDATE categories
                                      SET 
                                        $cat_image
                                        last_modified = '".date("Y-m-d H:i:s")."'
                                      WHERE 
                                        categories_id = '". (int)$row['categories_id']."'
                                      LIMIT 1";
                
                            tep_db_query($query);
                        } else {
                            // to add, we need to put stuff in categories and categories_description
                            $sql = "SELECT MAX( categories_id) max FROM categories";
                            $result = tep_db_query($sql);
                            $row =  tep_db_fetch_array($result);
                            $max_category_id = $row['max']+1;
                            if (!is_numeric($max_category_id) ){
                                $max_category_id=1;
                            }
                            $sql = "INSERT INTO categories (
                                        categories_id,
                                        parent_id,
                                        categories_image,
                                        sort_order,
                                        date_added,
                                        last_modified
                                   ) VALUES (
                                        $max_category_id,
                                        $theparent_id,
                                        '".tep_db_input($v_categories_image[$categorylevel])."',
                                        0,
                                        '".date("Y-m-d H:i:s")."',
                                        '".date("Y-m-d H:i:s")."'
                                   )";
                            $result = tep_db_query($sql);
                            
                            foreach ($languages as $key => $lang){
                                $sql = "INSERT INTO categories_description (
                                                categories_id,
                                                language_id,
                                                categories_name
                                       ) VALUES (
                                                $max_category_id,
                                                '".$lang['id']."',
                                                '".(!empty($v_categories_name[$categorylevel][$lang['id']])?tep_db_input($v_categories_name[$categorylevel][$lang['id']]):'')."'
                                       )";
                                tep_db_query($sql);
                            }
                            
                            $thiscategoryid = $max_category_id;
                        }
                        // the current catid is the next level's parent
                        $theparent_id = $thiscategoryid;
                        $v_categories_id = $thiscategoryid; // keep setting this, we need the lowest level category ID later
                    }
				 // }
                }
            }

              
            if ($v_products_model != "") {
                //   products_model exists!
                foreach ($items as $tkey => $item) {
                    print_el($item);
                }
        
                // find the vendor id from the name imported
                if ($options_array['option_mvs']) {
                    $vend_result = tep_db_query("SELECT vendors_id FROM vendors WHERE vendors_name = '". $v_vendor . "'");
                    $vend_row = tep_db_fetch_array($vend_result);
                    $v_vendor_id = $vend_row['vendors_id'];
                }

                // process the PRODUCTS table
                $result = tep_db_query("SELECT products_id FROM products WHERE (products_model = '". tep_db_input($v_products_model) . "')");
        
                // First we check to see if this is a product in the current db.
                if (tep_db_num_rows($result) == 0)  {
                
                    //   insert into products
                    echo "<font color='green'> !New Product!</font><br />";
        
                    // /////////////////////////////////////////////////////////////////////
                    //
                    // Start: Support for other contributions
                    //
                    // /////////////////////////////////////////////////////////////////////
                    $ep_additional_fields = '';
                    $ep_additional_data = '';

                    foreach ($custom_fields['products'] as $key => $name) { 
                        $ep_additional_fields .= $key . ',';
                    }

                    foreach ($custom_fields['products'] as $key => $name) { 
                        $tmp_var = 'v_' . $key;
                        $ep_additional_data .= "'" . $$tmp_var . "',";
                    }

                    if ($options_array['option_pdf_upload']) { 
                        $ep_additional_fields .= 'products_pdfupload,products_fileupload,';
                        $ep_additional_data .= "'$v_products_pdfupload','$v_products_fileupload',";
                    }
					
                    if ($options_array['option_mvs']) {
                        $ep_additional_fields .= 'vendors_id,';
                        $ep_additional_data .= "'$v_vendor_id',";
                    }
			
                    if ($options_array['option_master_products']) {
                        $ep_additional_fields .= 'products_master, products_master_status,';
                        $ep_additional_data .= "'$v_products_master','$v_products_master_status',";
                    }

                    // /////////////////////////////////////////////////////////////////////
                    // End: Support for other contributions
                    // /////////////////////////////////////////////////////////////////////
                    
                    $query = "INSERT INTO products (
                                products_image,
                                $ep_additional_fields
                                products_model,
                                products_price,
                                products_status,
                                products_last_modified,
                                products_date_added,
                                products_date_available,
                                products_tax_class_id,
                                products_weight,
                                products_quantity,
                                manufacturers_id )
                              VALUES (
                                ".(!empty($v_products_image)?"'".$v_products_image."'":'NULL').",
                                $ep_additional_data
                                '$v_products_model',
                                '$v_products_price',
                                '$v_db_status',
                                '".date("Y-m-d H:i:s")."',
                                ".$v_date_added.",
                                ".$v_date_avail.",
                                '$v_tax_class_id',
                                '$v_products_weight',
                                '$v_products_quantity',
                                ".(!empty($v_manufacturer_id)?$v_manufacturer_id:'NULL').")
                                ";
                    $result = tep_db_query($query);
                    
                    $v_products_id = tep_db_insert_id();
        
                } else {
        
                    // existing product(s), get the id from the query
                    // and update the product data
                    while ($row = tep_db_fetch_array($result)) {
            
                        $v_products_id = $row['products_id'];
                        echo "<font color='black'> Updated</font><br />";
                        
                        // /////////////////////////////////////////////////////////////////////
                        //
                        // Start: Support for other contributions
                        //
                        // /////////////////////////////////////////////////////////////////////
                        $ep_additional_updates = '';

                        foreach ($custom_fields['products'] as $key => $name) { 
                            $tmp_var = 'v_' . $key;
                            $ep_additional_updates .= $key . "='" . $$tmp_var . "',";
                        }

                        if ($options_array['option_pdf_upload']) {
                            $ep_additional_updates .= "products_pdfupload='$v_products_pdfupload',products_fileupload='$v_products_fileupload',";
                        }

                        if ($options_array['option_mvs']) {
                            $ep_additional_updates .= "vendors_id='$v_vendor_id',";
                        }

                        if ($options_array['option_master_products']) {
                            $ep_additional_updates .= "products_master='$v_products_master',products_master_status='$v_products_master_status',";
                        }
                        
                        // /////////////////////////////////////////////////////////////////////
                        // End: Support for other contributions
                        // /////////////////////////////////////////////////////////////////////
                        // only include the products image if it has been included in the spreadsheet
                        $tmp_products_image_update = '';
                        if (isset($v_products_image)) {
                            $tmp_products_image_update = "products_image=".(!empty($v_products_image)?"'".$v_products_image."'":'NULL').", ";
                        }
       
                        $query = "UPDATE products
                                  SET
                                    products_price='$v_products_price', 
                                    $tmp_products_image_update 
                                    $ep_additional_updates
                                    products_weight='$v_products_weight', 
                                    products_tax_class_id='$v_tax_class_id', 
                                    products_date_available=".$v_date_avail.", 
                                    products_date_added=".$v_date_added.", 
                                    products_last_modified='".date("Y-m-d H:i:s")."', 
                                    products_quantity = $v_products_quantity, 
                                    manufacturers_id = ".(!empty($v_manufacturer_id)?$v_manufacturer_id:'NULL').", 
                                    products_status = $v_db_status
                                  WHERE
                                    (products_id = $v_products_id)
                                  LIMIT 1";
            
                        tep_db_query($query);
                    }
                }
		
                if (isset($v_products_specials_price)) {
                    if ($options_array['option_sppc']) { 
                        $SPPC_extra_query = ' and customers_group_id = 0'; } else { $SPPC_extra_query = ''; 
                    }
                    $result = tep_db_query('select * from specials WHERE products_id = ' . $v_products_id . $SPPC_extra_query );

                    if ($v_products_specials_price == '') {
                    
                        $result = tep_db_query('DELETE FROM specials WHERE products_id = ' . $v_products_id . $SPPC_extra_query );
                        if ($options_array['option_sppc']) { 
                            $result = tep_db_query('DELETE FROM specials_retail_prices WHERE products_id = ' . $v_products_id );
                        }

                    } else {
                        if ($specials = tep_db_fetch_array($result)) {
                            $sql_data_array = array('products_id' => $v_products_id,
                                  'specials_new_products_price' => $v_products_specials_price,
                                  'specials_last_modified' => 'now()'
                            );
                            tep_db_perform('specials', $sql_data_array, 'update', 'specials_id = '.$specials['specials_id']);
                         
                            if ($options_array['option_sppc']) { 
                                $sql_data_array = array('products_id' => $v_products_id,'specials_new_products_price' => $v_products_specials_price);
                                tep_db_perform('specials_retail_prices', $sql_data_array, 'update', 'products_id = '.$v_products_id);
                            }
                        } else {
                            $sql_data_array = array('products_id' => $v_products_id,
                                  'specials_new_products_price' => $v_products_specials_price,
                                  'specials_date_added' => 'now()',
                                  'status' => '1'
                            );
                            
                            if ($options_array['option_sppc']) { 
                                $sql_data_array = array_merge($sql_data_array,array('customers_group_id' => '0')); 
                            }
                            tep_db_perform('specials', $sql_data_array, 'insert');
                         
                            if ($options_array['option_sppc']) { 
                                $sql_data_array = array('products_id' => $v_products_id,
                                      'specials_new_products_price' => $v_products_specials_price,
                                      'status' => '1',
                                      'customers_group_id' => '0'
                                );
                                tep_db_perform('specials_retail_prices', $sql_data_array, 'insert');
                            }
                        }
                    }
                }
			
                // upgrade method only. Note: if you upgrades more and more the id number will be hihger. I suggest that picture upgrades use last
                // or delete always v_products_images_image_1 column to prevent effect
                if ($options_array['option_product_images']) { 
                    if (isset($filelayout['v_products_images_image_1'])) {
                        tep_db_query("delete from products_images where products_id = '" . (int)$v_products_id . "'");
                        for ($i = 1; $i <= EP_PRODUCTS_IMAGES_MAX; ++$i) {
                            $pi_htmlcontent_var = 'v_products_images_htmlcontent_'.$i;
                            $pi_image_var = 'v_products_images_image_'.$i;
                            if (!empty($$pi_image_var) || !empty($$pi_htmlcontent_var)) {
                                tep_db_query("insert into products_images (products_id, image, htmlcontent, sort_order) values ('" . (int)$v_products_id . "', '" . tep_db_input($$pi_image_var) . "', '" . tep_db_input($$pi_htmlcontent_var) . "', '" . tep_db_input($i) . "')");
                            }
                        }
                    }
                }
        
                if ($options_array['option_quantity_prices']) { 
                    if (isset($filelayout['v_products_qpbp_price_1'])) {
                        tep_db_query("delete from products_price_break where products_id = '" . (int)$v_products_id . "'");
                        for ($i=1;$i<=EP_QPBP_MAX;$i++) {
                            $pi_htmlcontent_var = 'v_products_qpbp_price_'.$i;
                            $pi_image_var = 'v_products_qpbp_qty_'.$i;
                            if (!empty($$pi_image_var) || !empty($$pi_htmlcontent_var)) {
                                tep_db_query("insert into products_price_break (products_id, products_price, products_qty) values ('" . (int)$v_products_id . "', '" . tep_db_input($$pi_image_var) . "', '" . tep_db_input($$pi_htmlcontent_var) . "')");
                            }
                        }
                    }
                }

                // process the PRODUCTS_DESCRIPTION table
                foreach ($languages as $tkey => $lang){

                    $doit = false;
                    foreach ($custom_fields['products_description'] as $key => $name) { 
                        if (isset($filelayout['v_' . $key . '_'.$lang['id']])) { $doit = true; }
                    }

                    if ( isset($filelayout['v_products_name_'.$lang['id']]) || isset($filelayout['v_products_description_'.$lang['id']]) || isset($filelayout['v_products_url_'.$lang['id']]) || isset($filelayout['v_products_seo_title_'.$lang['id']]) || $doit == true ) {
        
                        $sql = "SELECT * FROM products_description WHERE
                                products_id = " . (int)$v_products_id . " AND
                                language_id = " . (int)$lang['id'];
                        $result = tep_db_query($sql);
        
                        $products_var = 'v_products_name_'.$lang['id'];
                        $description_var = 'v_products_description_'.$lang['id'];
                        $url_var = 'v_products_url_'.$lang['id'];

                        // /////////////////////////////////////////////////////////////////////
                        //
                        // Start: Support for other contributions
                        //
                        // /////////////////////////////////////////////////////////////////////
                        $ep_additional_updates = '';
                        $ep_additional_fields = '';
                        $ep_additional_data = '';

                        foreach ($custom_fields['products_description'] as $key => $name) { 
                            $tmp_var = 'v_' . $key . '_' . $lang['id'];
                            $ep_additional_updates .= $key . " = '" . tep_db_input($$tmp_var) ."',";
                            $ep_additional_fields .= $key . ",";
                            $ep_additional_data .= "'". tep_db_input($$tmp_var) . "',";
                        }

                        // header tags controller support
                        if (isset($filelayout['v_products_seo_title_'.$lang['id']])){
                            $head_title_tag_var = 'v_products_seo_title_'.$lang['id'];
                            $head_desc_tag_var = 'v_products_seo_description_'.$lang['id'];
                            $head_keywords_tag_var = 'v_products_seo_keywords_'.$lang['id'];
          
                            $ep_additional_updates .= "products_seo_title = '" . tep_db_input($$head_title_tag_var) ."', products_seo_description = '" . tep_db_input($$head_desc_tag_var) ."', products_seo_keywords = '" . tep_db_input($$head_keywords_tag_var) ."',";
                            $ep_additional_fields .= "products_seo_title,products_seo_description,products_seo_keywords,";
                            $ep_additional_data .= "'". tep_db_input($$head_title_tag_var) . "','". tep_db_input($$head_desc_tag_var) . "','". tep_db_input($$head_keywords_tag_var) . "',";
                        }
                        // end: header tags controller support
                        
                        // /////////////////////////////////////////////////////////////////////
                        // End: Support for other contributions
                        // /////////////////////////////////////////////////////////////////////
        
                        
                        // existing product?
                        if (tep_db_num_rows($result) > 0) {
                            // already in the description, let's just update it
                            $sql =
                                "UPDATE products_description 
                                 SET
                                    products_name='" . tep_db_input($$products_var) . "',
                                    products_description='" . tep_db_input($$description_var) . "',
                                    $ep_additional_updates
                                    products_url='" . $$url_var . "'
                                 WHERE
                                    products_id = '" . (int)$v_products_id . "' AND
                                    language_id = '" . (int)$lang['id'] ."'
                                 LIMIT 1";
                            $result = tep_db_query($sql);
        
                        } else {
        
                            // nope, this is a new product description
                            $result = tep_db_query($sql);
                            $sql =
                                "INSERT INTO products_description
                                    ( products_id,
                                      language_id,
                                      products_name,
                                      products_description,
                                      $ep_additional_fields
                                      products_url
                                    )
                                 VALUES (
                                        '" . (int)$v_products_id . "',
                                        " . (int)$lang['id'] . ",
                                        '". tep_db_input($$products_var) . "',
                                        '". tep_db_input($$description_var) . "',
                                        $ep_additional_data
                                        '". $$url_var . "'
                                        )";
                            $result = tep_db_query($sql);
                        }
                    }
                }              
        
                if (isset($v_categories_id)){
                    //find out if this product is listed in the category given
                    $result_incategory = tep_db_query("SELECT
                                products_to_categories.products_id,
                                products_to_categories.categories_id
                                FROM
                                    products_to_categories
                                WHERE
                                products_to_categories.products_id='" . (int)$v_products_id . "' AND
                                products_to_categories.categories_id='" . (int)$v_categories_id . "'");
        
                    if (tep_db_num_rows($result_incategory) == 0) {
                        // nope, this is a new category for this product
                        $res1 = tep_db_query('INSERT INTO products_to_categories (products_id, categories_id)
                                              VALUES ("' . (int)$v_products_id . '", "' . (int)$v_categories_id . '")');
                    } else {
                        // already in this category, nothing to do!
                    }
                }
        
                // this is for the cross sell contribution
                if (isset($v_cross_sell)) {
                    tep_db_query("delete from products_xsell where products_id = " . $v_products_id . " or xsell_id = " . $v_products_id . "");
                    if (!empty($v_cross_sell)){
                        $xsells_array = explode(',',$v_cross_sell);
                        foreach ($xsells_array as $xs_key => $xs_model ) {
                            $cross_sell_sql = "select products_id from products where products_model = '" . trim($xs_model) . "' limit 1";
                            $cross_sell_result = tep_db_query($cross_sell_sql);
                            $cross_sell_row = tep_db_fetch_array($cross_sell_result);
                            
                            tep_db_query("insert into products_xsell (products_id, xsell_id, sort_order) 
                                          values ( ".$v_products_id.", ".$cross_sell_row['products_id'].", 1)");
                            tep_db_query("insert into products_xsell (products_id, xsell_id, sort_order) 
                                          values ( ".$cross_sell_row['products_id'].", ". (int)$v_products_id.", 1)");
                        }  
                    }
             		 }

                // for the separate prices per customer (SPPC) module
                $ll=1;
                if (isset($v_customer_price_1)){
                    
                    if (($v_customer_group_id_1 == '') && ($v_customer_price_1 != ''))  {
                        echo "<font color=red>ERROR - v_customer_group_id and v_customer_price must occur in pairs</font>";
                        die();
                    }
                    // they spec'd some prices, so clear all existing entries
                    $result = tep_db_query("DELETE FROM products_groups WHERE products_id = '" . (int)$v_products_id . "'");
                // and insert the new record
                                 if ($v_customer_price_1 != ''){                                   
                                         $result = tep_db_query(" INSERT INTO products_groups (customers_group_id, customers_group_price, products_id)
                                                                 VALUES
                                                                 ('"
                                                                  . $v_customer_group_id_1 . "', '"
                                                                  . $v_customer_price_1 . "', '"
                                                                  . (int)$v_products_id
                                                                  . "')");
                                 }
                                 if ($v_customer_price_2 != ''){
                                         $result = tep_db_query(" INSERT INTO products_groups (customers_group_id, customers_group_price, products_id)
                                                                 VALUES
                                                                 ('"
                                                                  . $v_customer_group_id_2 . "', '"
                                                                  . $v_customer_price_2 . "', '"
                                                                  . (int)$v_products_id
                                                                  . "')");
                                 }
                                 if ($v_customer_price_3 != ''){
                                         $result = tep_db_query(" INSERT INTO products_groups (customers_group_id, customers_group_price, products_id)
                                                                 VALUES
                                                                 ('"
                                                                  . $v_customer_group_id_3 . "', '"
                                                                  . $v_customer_price_3 . "', '"
                                                                  . (int)$v_products_id
                                                                  . "')");
                                 }
                                 if ($v_customer_price_4 != ''){
                                 $result = tep_db_query(" INSERT INTO products_groups (customers_group_id, customers_group_price, products_id)
                                                                 VALUES
                                                                 ('"
                                                                  . $v_customer_group_id_4 . "', '"
                                                                  . $v_customer_price_4 . "', '"
                                                                  . (int)$v_products_id
                                                                  . "')");
                                 }

                    if (isset($v_customer_specials_price_1)) {
                        $result = tep_db_query('select * from specials WHERE products_id = ' . $v_products_id . ' and customers_group_id = 1' );

                        if ($v_customer_specials_price_1 == '') {			  
                            $result = tep_db_query('DELETE FROM specials WHERE products_id = ' . $v_products_id . ' and customers_group_id = 1' );
                        } else {
                            if ($specials = tep_db_fetch_array($result)) {
                                $sql_data_array = array('products_id' => (int)$v_products_id,
                                      'specials_new_products_price' => $v_customer_specials_price_1,
                                      'specials_last_modified' => 'now()'
                                );
                                tep_db_perform('specials', $sql_data_array, 'update', 'specials_id = '.$specials['specials_id']);
                                                 } else {
                                $sql_data_array = array('products_id' => (int)$v_products_id,
                                      'specials_new_products_price' => $v_customer_specials_price_1,
                                      'specials_date_added' => 'now()',
                                      'status' => '1',
                                      'customers_group_id' => '1'
                                );
                                tep_db_perform('specials', $sql_data_array, 'insert');
                            }
                        }
                    }			
                }
                // end: separate prices per customer (SPPC) module
        
        
                // VJ product attribs begin
                if (isset($v_attribute_options_id_1)){
                    $attribute_rows = 1; // master row count
        
                    // product options count
                    $attribute_options_count = 1;
                    $v_attribute_options_id_var = 'v_attribute_options_id_' . $attribute_options_count;
        
                    while (isset($$v_attribute_options_id_var) && !empty($$v_attribute_options_id_var)) {
                        // remove product attribute options linked to this product before proceeding further
                        // this is useful for removing attributes linked to a product
                        $attributes_clean_query = "delete from products_attributes where products_id = '" . (int)$v_products_id . "' and options_id = '" . (int)$$v_attribute_options_id_var . "'";
        
                        tep_db_query($attributes_clean_query);
        
                        $attribute_options_query = "select products_options_name from products_options where products_options_id = '" . (int)$$v_attribute_options_id_var . "'";
        
                        $attribute_options_values = tep_db_query($attribute_options_query);
        
                        // option table update begin
                        if ($attribute_rows == 1) {
                            // insert into options table if no option exists
                            if (tep_db_num_rows($attribute_options_values) <= 0) {
                                for ($i=0, $n=sizeof($languages); $i<$n; $i++) {
                                    $lid = $languages[$i]['id'];
        
                                  $v_attribute_options_name_var = 'v_attribute_options_name_' . $attribute_options_count . '_' . $lid;
        
                                    if (isset($$v_attribute_options_name_var)) {
                                        $attribute_options_insert_query = "insert into products_options (products_options_id, language_id, products_options_name) values ('" . (int)$$v_attribute_options_id_var . "', '" . (int)$lid . "', '" . $$v_attribute_options_name_var . "')";       
                                        $attribute_options_insert = tep_db_query($attribute_options_insert_query);
                                    }
                                }
                            } else { // update options table, if options already exists
                                for ($i=0, $n=sizeof($languages); $i<$n; $i++) {
                                    $lid = $languages[$i]['id'];
        
                                    $v_attribute_options_name_var = 'v_attribute_options_name_' . $attribute_options_count . '_' . $lid;
        
                                    if (isset($$v_attribute_options_name_var)) {
                                        $attribute_options_update_lang_query = "select products_options_name from products_options where products_options_id = '" . (int)$$v_attribute_options_id_var . "' and language_id ='" . (int)$lid . "'";        
                                        $attribute_options_update_lang_values = tep_db_query($attribute_options_update_lang_query);
        
                                        // if option name doesn't exist for particular language, insert value
                                        if (tep_db_num_rows($attribute_options_update_lang_values) <= 0) {
                                            $attribute_options_lang_insert_query = "insert into products_options (products_options_id, language_id, products_options_name) values ('" . (int)$$v_attribute_options_id_var . "', '" . (int)$lid . "', '" . $$v_attribute_options_name_var . "')";       
                                            $attribute_options_lang_insert = tep_db_query($attribute_options_lang_insert_query);
                                        } else { // if option name exists for particular language, update table
                                            $attribute_options_update_query = "update products_options set products_options_name = '" . $$v_attribute_options_name_var . "' where products_options_id ='" . (int)$$v_attribute_options_id_var . "' and language_id = '" . (int)$lid . "'";        
                                            $attribute_options_update = tep_db_query($attribute_options_update_query);
                                        }
                                    }
                                }
                            }
                        }
                        // option table update end
        
                        // product option values count
                        $attribute_values_count = 1;
                        $v_attribute_values_id_var = 'v_attribute_values_id_' . $attribute_options_count . '_' . $attribute_values_count;
        
                        while (isset($$v_attribute_values_id_var) && !empty($$v_attribute_values_id_var)) {
                            $attribute_values_query = "select products_options_values_name from products_options_values where products_options_values_id = '" . (int)$$v_attribute_values_id_var . "'";
        
                            $attribute_values_values = tep_db_query($attribute_values_query);
        
                            // options_values table update begin
                            if ($attribute_rows == 1) {
                                // insert into options_values table if no option exists
                                if (tep_db_num_rows($attribute_values_values) <= 0) {
                                    for ($i=0, $n=sizeof($languages); $i<$n; $i++) {
                                        $lid = $languages[$i]['id'];
        
                                        $v_attribute_values_name_var = 'v_attribute_values_name_' . $attribute_options_count . '_' . $attribute_values_count . '_' . $lid;
        
                                        if (isset($$v_attribute_values_name_var)) {
                                            $attribute_values_insert_query = "insert into products_options_values (products_options_values_id, language_id, products_options_values_name) values ('" . (int)$$v_attribute_values_id_var . "', '" . (int)$lid . "', '" . tep_db_input($$v_attribute_values_name_var) . "')";        
                                            $attribute_values_insert = tep_db_query($attribute_values_insert_query);
                                        }
                                    }
        
        
                                    // insert values to pov2po table
                                    $attribute_values_pov2po_query = "insert into products_options_values_to_products_options (products_options_id, products_options_values_id) values ('" . (int)$$v_attribute_options_id_var . "', '" . (int)$$v_attribute_values_id_var . "')";        
                                    $attribute_values_pov2po = tep_db_query($attribute_values_pov2po_query);
                                } else { // update options table, if options already exists
                                    for ($i=0, $n=sizeof($languages); $i<$n; $i++) {
                                        $lid = $languages[$i]['id'];
        
                                        $v_attribute_values_name_var = 'v_attribute_values_name_' . $attribute_options_count . '_' . $attribute_values_count . '_' . $lid;
        
                                        if (isset($$v_attribute_values_name_var)) {
                                            $attribute_values_update_lang_query = "select products_options_values_name from products_options_values where products_options_values_id = '" . (int)$$v_attribute_values_id_var . "' and language_id ='" . (int)$lid . "'";        
                                            $attribute_values_update_lang_values = tep_db_query($attribute_values_update_lang_query);
        
                                            // if options_values name doesn't exist for particular language, insert value
                                            if (tep_db_num_rows($attribute_values_update_lang_values) <= 0) {
                                                $attribute_values_lang_insert_query = "insert into products_options_values (products_options_values_id, language_id, products_options_values_name) values ('" . (int)$$v_attribute_values_id_var . "', '" . (int)$lid . "', '" . tep_db_input($$v_attribute_values_name_var) . "')";
                                                $attribute_values_lang_insert = tep_db_query($attribute_values_lang_insert_query);
                                            } else { // if options_values name exists for particular language, update table
                                                $attribute_values_update_query = "update products_options_values set products_options_values_name = '" . tep_db_input($$v_attribute_values_name_var) . "' where products_options_values_id ='" . (int)$$v_attribute_values_id_var . "' and language_id = '" . (int)$lid . "'";
                                                $attribute_values_update = tep_db_query($attribute_values_update_query);
                                            }
                                        }
                                    }
                                }
                            }
                            // options_values table update end
        
                            // options_values price update begin
                          $v_attribute_values_price_var = 'v_attribute_values_price_' . $attribute_options_count . '_' . $attribute_values_count;
        
                            if (isset($$v_attribute_values_price_var) && ($$v_attribute_values_price_var != '')) {
                                $attribute_prices_query = "select options_values_price, price_prefix from products_attributes where products_id = '" . (int)$v_products_id . "' and options_id ='" . (int)$$v_attribute_options_id_var . "' and options_values_id = '" . (int)$$v_attribute_values_id_var . "'";
        
                                $attribute_prices_values = tep_db_query($attribute_prices_query);
                                $attribute_values_price_prefix = ($$v_attribute_values_price_var < 0) ? '-' : '+';
                                // if negative, remove the negative sign for storing since the prefix is stored in another field.
                                if ( $$v_attribute_values_price_var < 0 ) $$v_attribute_values_price_var = strval(-((float)$$v_attribute_values_price_var));
        
                                // options_values_prices table update begin
                                // insert into options_values_prices table if no price exists
                                if (tep_db_num_rows($attribute_prices_values) <= 0) {
                                    $attribute_prices_insert_query = "insert into products_attributes (products_id, options_id, options_values_id, options_values_price, price_prefix) values ('" . (int)$v_products_id . "', '" . (int)$$v_attribute_options_id_var . "', '" . (int)$$v_attribute_values_id_var . "', '" . (float)$$v_attribute_values_price_var . "', '" . $attribute_values_price_prefix . "')";
                                    $attribute_prices_insert = tep_db_query($attribute_prices_insert_query);
                                } else { // update options table, if options already exists
                                    $attribute_prices_update_query = "update products_attributes set options_values_price = '" . $$v_attribute_values_price_var . "', price_prefix = '" . $attribute_values_price_prefix . "' where products_id = '" . (int)$v_products_id . "' and options_id = '" . (int)$$v_attribute_options_id_var . "' and options_values_id ='" . (int)$$v_attribute_values_id_var . "'";
                                    $attribute_prices_update = tep_db_query($attribute_prices_update_query);
                                }
                            }
                            // options_values price update end
        
                            //////// attributes stock add start
                            $v_attribute_values_stock_var = 'v_attribute_values_stock_' . $attribute_options_count . '_' . $attribute_values_count;
                        
                            if (isset($$v_attribute_values_stock_var) && ($$v_attribute_values_stock_var != '')) {
                                
                                $stock_attributes = $$v_attribute_options_id_var.'-'.$$v_attribute_values_id_var;
                                $attribute_stock_query = tep_db_query("select products_stock_quantity from products_stock where products_id = '" . (int)$v_products_id . "' and products_stock_attributes ='" . $stock_attributes . "'");        
                                
                                // insert into products_stock_quantity table if no stock exists
                                if (tep_db_num_rows($attribute_stock_query) <= 0) {
                                    $attribute_stock_insert_query =tep_db_query("insert into products_stock (products_id, products_stock_attributes, products_stock_quantity) values ('" . (int)$v_products_id . "', '" . $stock_attributes . "', '" . (int)$$v_attribute_values_stock_var . "')");                                        
                                } else { // update options table, if options already exists
                                    $attribute_stock_insert_query = tep_db_query("update products_stock set products_stock_quantity = '" . (int)$$v_attribute_values_stock_var . "' where products_id = '" . (int)$v_products_id . "' and products_stock_attributes = '" . $stock_attributes . "'");
                                                
                                    // turn on stock tracking on products_options table
                                    $stock_tracking_query = tep_db_query("update products_options set products_options_track_stock = '1' where products_options_id = '" . (int)$$v_attribute_options_id_var . "'");                                
                                }
                            }
                            //////// attributes stock add end                    
                            
                            $attribute_values_count++;
                            $v_attribute_values_id_var = 'v_attribute_values_id_' . $attribute_options_count . '_' . $attribute_values_count;
                        }
        
                        $attribute_options_count++;
                        $v_attribute_options_id_var = 'v_attribute_options_id_' . $attribute_options_count;
                    }
        
                    $attribute_rows++;
                }
                // VJ product attribs end
        
            } else {
                // this record was missing the product_model
                echo "<p class=>No products_model field in record. This line was not imported: ";
                foreach ($items as $tkey => $item) {
                    print_el($item);
                }
                echo "<br /><br /></p>";
            }
            // end of row insertion code
            
        }

    // EP for product extra fields Contrib by minhmaster DEVSOFTVN ==========
    }
    // end (EP for product extra fields Contrib by minhmt DEVSOFTVN) ============

}
?>

<script type="text/javascript"> 
function switchForm( field ) {
  var d = document;
  var frm = field.form;
  var tbl = d.getElementById("customtable");
      
  if (d.getElementById) {
      if (field.options[field.selectedIndex].text == 'Complete' || field.options[field.selectedIndex].text == 'Google Shopping') {
          tbl.style.backgroundColor='lightgrey';
          for ( var index = 0; index < frm.elements.length; index++ ) {
              var oElement = frm.elements[ index ];
              if ( oElement.type == "checkbox" ) {
                  if ( oElement.checked ) {
                    oElement.checked = false;
                  }
                  oElement.checked = true;
                  oElement.disabled = true;
              }
          }
      } 

      else if (field.options[field.selectedIndex].text == 'Price/Qty' || field.options[field.selectedIndex].text == 'Categories' || field.options[field.selectedIndex].text == 'Attributes' ) {
          tbl.style.backgroundColor='lightblue';
          for ( var index = 0; index < frm.elements.length; index++ ) {
              var oElement = frm.elements[ index ];
              if ( oElement.type == "checkbox" ) {
                  if ( oElement.checked ) {
                      oElement.checked = false;
                  }
                  if ( (oElement.name == 'epcust_price' || oElement.name == 'epcust_quantity') && field.options[field.selectedIndex].text == 'Price/Qty' ) {
                      oElement.disabled = false;
                      oElement.checked = true;
                  } 
                  else if ( oElement.name == 'epcust_category' && field.options[field.selectedIndex].text == 'Categories' ) {
                      oElement.disabled = false;
                      oElement.checked = true;
                  } 
                  else if ( oElement.name == 'epcust_attributes' && field.options[field.selectedIndex].text == 'Attributes' ) {
                      oElement.disabled = false;
                      oElement.checked = true;
                  }    
              } 
              else {
                 // oElement.disabled = true;
              }
          }
      }
      else if (field.options[field.selectedIndex].text == 'Custom') {
          tbl.style.backgroundColor='white';
          for ( var index = 0; index < frm.elements.length; index++ ) {
              var oElement = frm.elements[ index ];
              oElement.disabled = false;
              oElement.checked = false;
          }       
      } 
  } 
  else { 
      tbl.style.backgroundColor='white';

      for ( var index = 0; index < frm.elements.length; index++ ) {
          var oElement = frm.elements[ index ];
          if ( oElement.type == "checkbox" ) {
              oElement.disabled = false;
          }
      }
  }
} 
   
$('#check-image-usage').on( "click", function() { 
  $.post( "easypopulate_ajax.php", { fcn: "check-image-usage"})
  .done(function( data ) {
    $("#check-image-usage-success").html(data);
  });
}); 

$('#clear-temp-dir').on( "click", function() { 
  var locn = '<?php echo EP_TEMP_DIRECTORY; ?>';
  $.post( "easypopulate_ajax.php", { fcn: "cleartemp", locn: locn})
  .done(function( data ) {
    $("#clear-success").html(data);
  });
});  
</script> 
<?php
require('includes/template_bottom.php');
require('includes/application_bottom.php'); 
?>